/* DO NOT EDIT - This file generated automatically by api_exec_init.py script */

/*
 * Copyright (C) 2012 Intel Corporation
 * All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sub license,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT.  IN NO EVENT SHALL
 * Intel Corporation,
 * AND/OR THEIR SUPPLIERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
 * OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

/**
 * \file api_exec_init.c
 * Initialize dispatch table.
 */


#include "api_exec_decl.h"
#include "glapi/glapi.h"
#include "main/context.h"
#include "main/dispatch.h"


/**
 * Initialize a context's exec table with pointers to Mesa's supported
 * GL functions.
 *
 * This function depends on ctx->Version.
 *
 * \param ctx  GL context to which \c exec belongs.
 */
void
_mesa_initialize_exec_table(struct gl_context *ctx)
{
   struct _glapi_table *exec;

   exec = ctx->Exec;
   assert(exec != NULL);

   assert(ctx->Version > 0);

   if (!_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx) || (ctx->API == API_OPENGLES2 && ctx->Version >= 30))) {
      SET_BeginTransformFeedback(exec, _mesa_BeginTransformFeedback);
      SET_BindBufferRange(exec, _mesa_BindBufferRange);
      SET_BindFragDataLocation(exec, _mesa_BindFragDataLocation);
      SET_BindFragDataLocationIndexed(exec, _mesa_BindFragDataLocationIndexed);
      SET_BindSampler(exec, _mesa_BindSampler);
      SET_BindTransformFeedback(exec, _mesa_BindTransformFeedback);
      SET_BlendEquationSeparateiARB(exec, _mesa_BlendEquationSeparateiARB);
      SET_BlendEquationiARB(exec, _mesa_BlendEquationiARB);
      SET_BlendFuncSeparateiARB(exec, _mesa_BlendFuncSeparateiARB);
      SET_BlendFunciARB(exec, _mesa_BlendFunciARB);
      SET_BlitFramebuffer(exec, _mesa_BlitFramebuffer);
      SET_ClearBufferfi(exec, _mesa_ClearBufferfi);
      SET_ClearBufferfv(exec, _mesa_ClearBufferfv);
      SET_ClearBufferiv(exec, _mesa_ClearBufferiv);
      SET_ClearBufferuiv(exec, _mesa_ClearBufferuiv);
      SET_ClientWaitSync(exec, _mesa_ClientWaitSync);
      SET_CopyBufferSubData(exec, _mesa_CopyBufferSubData);
      SET_CopyImageSubData(exec, _mesa_CopyImageSubData);
      SET_DeleteSamplers(exec, _mesa_DeleteSamplers);
      SET_DeleteSync(exec, _mesa_DeleteSync);
      SET_EndTransformFeedback(exec, _mesa_EndTransformFeedback);
      SET_FenceSync(exec, _mesa_FenceSync);
      SET_FramebufferTextureLayer(exec, _mesa_FramebufferTextureLayer);
      SET_GenSamplers(exec, _mesa_GenSamplers);
      SET_InvalidateFramebuffer(exec, _mesa_InvalidateFramebuffer);
      SET_InvalidateSubFramebuffer(exec, _mesa_InvalidateSubFramebuffer);
      SET_MinSampleShading(exec, _mesa_MinSampleShading);
      SET_PauseTransformFeedback(exec, _mesa_PauseTransformFeedback);
      SET_ResumeTransformFeedback(exec, _mesa_ResumeTransformFeedback);
      SET_TexStorage2D(exec, _mesa_TexStorage2D);
      SET_TexStorage3D(exec, _mesa_TexStorage3D);
      SET_TransformFeedbackVaryings(exec, _mesa_TransformFeedbackVaryings);
      SET_UniformBlockBinding(exec, _mesa_UniformBlockBinding);
      SET_VertexAttribDivisor(exec, _mesa_VertexAttribDivisor);
      SET_VertexAttribIPointer(exec, _mesa_VertexAttribIPointer);
      SET_WaitSync(exec, _mesa_WaitSync);
   }
   if (!_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx) || (ctx->API == API_OPENGLES2 && ctx->Version >= 31))) {
      SET_BindImageTexture(exec, _mesa_BindImageTexture);
      SET_BindVertexBuffer(exec, _mesa_BindVertexBuffer);
      SET_BufferStorage(exec, _mesa_BufferStorage);
      SET_DispatchCompute(exec, _mesa_DispatchCompute);
      SET_DispatchComputeIndirect(exec, _mesa_DispatchComputeIndirect);
      SET_FramebufferSampleLocationsfvARB(exec, _mesa_FramebufferSampleLocationsfvARB);
      SET_MemoryBarrierByRegion(exec, _mesa_MemoryBarrierByRegion);
      SET_NamedFramebufferSampleLocationsfvARB(exec, _mesa_NamedFramebufferSampleLocationsfvARB);
      SET_PatchParameteri(exec, _mesa_PatchParameteri);
      SET_SampleMaski(exec, _mesa_SampleMaski);
      SET_TextureView(exec, _mesa_TextureView);
      SET_VertexAttribBinding(exec, _mesa_VertexAttribBinding);
      SET_VertexBindingDivisor(exec, _mesa_VertexBindingDivisor);
      SET_ViewportSwizzleNV(exec, _mesa_ViewportSwizzleNV);
   }
   if (!_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx) || (ctx->API == API_OPENGLES2 && ctx->Version >= 32))) {
      SET_BufferStorageMemEXT(exec, _mesa_BufferStorageMemEXT);
      SET_NamedBufferStorageMemEXT(exec, _mesa_NamedBufferStorageMemEXT);
   }
   if (!_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx) || ctx->API == API_OPENGLES || ctx->API == API_OPENGLES2)) {
      SET_ActiveTexture(exec, _mesa_ActiveTexture);
      SET_BindBuffer(exec, _mesa_BindBuffer);
      SET_BindTexture(exec, _mesa_BindTexture);
      SET_BlendEquationSeparate(exec, _mesa_BlendEquationSeparate);
      SET_BlendFunc(exec, _mesa_BlendFunc);
      SET_BlendFuncSeparate(exec, _mesa_BlendFuncSeparate);
      SET_BufferData(exec, _mesa_BufferData);
      SET_BufferSubData(exec, _mesa_BufferSubData);
      SET_CheckFramebufferStatus(exec, _mesa_CheckFramebufferStatus);
      SET_Clear(exec, _mesa_Clear);
      SET_CompressedTexImage2D(exec, _mesa_CompressedTexImage2D);
      SET_CompressedTexSubImage2D(exec, _mesa_CompressedTexSubImage2D);
      SET_ConservativeRasterParameterfNV(exec, _mesa_ConservativeRasterParameterfNV);
      SET_ConservativeRasterParameteriNV(exec, _mesa_ConservativeRasterParameteriNV);
      SET_CopyTexImage2D(exec, _mesa_CopyTexImage2D);
      SET_CopyTexSubImage2D(exec, _mesa_CopyTexSubImage2D);
      SET_CullFace(exec, _mesa_CullFace);
      SET_DeleteBuffers(exec, _mesa_DeleteBuffers);
      SET_DeleteTextures(exec, _mesa_DeleteTextures);
      SET_DepthFunc(exec, _mesa_DepthFunc);
      SET_FlushMappedBufferRange(exec, _mesa_FlushMappedBufferRange);
      SET_FramebufferRenderbuffer(exec, _mesa_FramebufferRenderbuffer);
      SET_FramebufferTexture2D(exec, _mesa_FramebufferTexture2D);
      SET_FrontFace(exec, _mesa_FrontFace);
      SET_GenBuffers(exec, _mesa_GenBuffers);
      SET_GenRenderbuffers(exec, _mesa_GenRenderbuffers);
      SET_GenTextures(exec, _mesa_GenTextures);
      SET_GenerateMipmap(exec, _mesa_GenerateMipmap);
      SET_LineWidth(exec, _mesa_LineWidth);
      SET_MapBuffer(exec, _mesa_MapBuffer);
      SET_MapBufferRange(exec, _mesa_MapBufferRange);
      SET_PixelStorei(exec, _mesa_PixelStorei);
      SET_ReadPixels(exec, _mesa_ReadPixels);
      SET_Scissor(exec, _mesa_Scissor);
      SET_StencilFunc(exec, _mesa_StencilFunc);
      SET_StencilOp(exec, _mesa_StencilOp);
      SET_SubpixelPrecisionBiasNV(exec, _mesa_SubpixelPrecisionBiasNV);
      SET_TexImage2D(exec, _mesa_TexImage2D);
      SET_TexSubImage2D(exec, _mesa_TexSubImage2D);
      SET_UnmapBuffer(exec, _mesa_UnmapBuffer);
      SET_Viewport(exec, _mesa_Viewport);
   }
   if (!_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx) || ctx->API == API_OPENGLES)) {
      SET_LogicOp(exec, _mesa_LogicOp);
      SET_PointSize(exec, _mesa_PointSize);
   }
   if (!_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx) || ctx->API == API_OPENGLES2)) {
      SET_ActiveShaderProgram(exec, _mesa_ActiveShaderProgram);
      SET_AttachShader(exec, _mesa_AttachShader);
      SET_BeginConditionalRender(exec, _mesa_BeginConditionalRender);
      SET_BindAttribLocation(exec, _mesa_BindAttribLocation);
      SET_BindProgramPipeline(exec, _mesa_BindProgramPipeline);
      SET_BindVertexArray(exec, _mesa_BindVertexArray);
      SET_ClipControl(exec, _mesa_ClipControl);
      SET_CompressedTexImage3D(exec, _mesa_CompressedTexImage3D);
      SET_CompressedTexSubImage3D(exec, _mesa_CompressedTexSubImage3D);
      SET_CopyTexSubImage3D(exec, _mesa_CopyTexSubImage3D);
      SET_CreateShader(exec, _mesa_CreateShader);
      SET_DeleteVertexArrays(exec, _mesa_DeleteVertexArrays);
      SET_DetachShader(exec, _mesa_DetachShader);
      SET_DisableVertexAttribArray(exec, _mesa_DisableVertexAttribArray);
      SET_DrawBuffers(exec, _mesa_DrawBuffers);
      SET_EnableVertexAttribArray(exec, _mesa_EnableVertexAttribArray);
      SET_EndConditionalRender(exec, _mesa_EndConditionalRender);
      SET_FramebufferTexture3D(exec, _mesa_FramebufferTexture3D);
      SET_GenProgramPipelines(exec, _mesa_GenProgramPipelines);
      SET_GenVertexArrays(exec, _mesa_GenVertexArrays);
      SET_GetUniformLocation(exec, _mesa_GetUniformLocation);
      SET_LinkProgram(exec, _mesa_LinkProgram);
      SET_ProgramParameteri(exec, _mesa_ProgramParameteri);
      SET_ReadBuffer(exec, _mesa_ReadBuffer);
      SET_ReadnPixelsARB(exec, _mesa_ReadnPixelsARB);
      SET_ShaderSource(exec, _mesa_ShaderSource);
      SET_StencilFuncSeparate(exec, _mesa_StencilFuncSeparate);
      SET_StencilMaskSeparate(exec, _mesa_StencilMaskSeparate);
      SET_StencilOpSeparate(exec, _mesa_StencilOpSeparate);
      SET_TexImage3D(exec, _mesa_TexImage3D);
      SET_TexSubImage3D(exec, _mesa_TexSubImage3D);
      SET_UseProgram(exec, _mesa_UseProgram);
      SET_UseProgramStages(exec, _mesa_UseProgramStages);
      SET_VertexAttribPointer(exec, _mesa_VertexAttribPointer);
   }
   if (!_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx))) {
      SET_AlphaToCoverageDitherControlNV(exec, _mesa_AlphaToCoverageDitherControlNV);
      SET_AttachObjectARB(exec, _mesa_AttachObjectARB);
      SET_BindBufferOffsetEXT(exec, _mesa_BindBufferOffsetEXT);
      SET_BindImageTextures(exec, _mesa_BindImageTextures);
      SET_BindSamplers(exec, _mesa_BindSamplers);
      SET_BindTextures(exec, _mesa_BindTextures);
      SET_BindVertexBuffers(exec, _mesa_BindVertexBuffers);
      SET_ClearBufferData(exec, _mesa_ClearBufferData);
      SET_ClearBufferSubData(exec, _mesa_ClearBufferSubData);
      SET_CompressedTexImage1D(exec, _mesa_CompressedTexImage1D);
      SET_CompressedTexSubImage1D(exec, _mesa_CompressedTexSubImage1D);
      SET_CopyImageSubDataNV(exec, _mesa_CopyImageSubDataNV);
      SET_CopyTexImage1D(exec, _mesa_CopyTexImage1D);
      SET_CopyTexSubImage1D(exec, _mesa_CopyTexSubImage1D);
      SET_CreateShaderObjectARB(exec, _mesa_CreateShaderObjectARB);
      SET_DetachObjectARB(exec, _mesa_DetachObjectARB);
      SET_DispatchComputeGroupSizeARB(exec, _mesa_DispatchComputeGroupSizeARB);
      SET_DrawBuffer(exec, _mesa_DrawBuffer);
      SET_FramebufferTexture1D(exec, _mesa_FramebufferTexture1D);
      SET_GetImageHandleARB(exec, _mesa_GetImageHandleARB);
      SET_GetTextureHandleARB(exec, _mesa_GetTextureHandleARB);
      SET_GetTextureSamplerHandleARB(exec, _mesa_GetTextureSamplerHandleARB);
      SET_InvalidateBufferData(exec, _mesa_InvalidateBufferData);
      SET_InvalidateBufferSubData(exec, _mesa_InvalidateBufferSubData);
      SET_InvalidateTexImage(exec, _mesa_InvalidateTexImage);
      SET_InvalidateTexSubImage(exec, _mesa_InvalidateTexSubImage);
      SET_IsImageHandleResidentARB(exec, _mesa_IsImageHandleResidentARB);
      SET_IsTextureHandleResidentARB(exec, _mesa_IsTextureHandleResidentARB);
      SET_MakeImageHandleNonResidentARB(exec, _mesa_MakeImageHandleNonResidentARB);
      SET_MakeImageHandleResidentARB(exec, _mesa_MakeImageHandleResidentARB);
      SET_MakeTextureHandleNonResidentARB(exec, _mesa_MakeTextureHandleNonResidentARB);
      SET_MakeTextureHandleResidentARB(exec, _mesa_MakeTextureHandleResidentARB);
      SET_PixelStoref(exec, _mesa_PixelStoref);
      SET_PolygonMode(exec, _mesa_PolygonMode);
      SET_PrimitiveRestartIndex(exec, _mesa_PrimitiveRestartIndex);
      SET_ShaderStorageBlockBinding(exec, _mesa_ShaderStorageBlockBinding);
      SET_TexImage1D(exec, _mesa_TexImage1D);
      SET_TexStorage1D(exec, _mesa_TexStorage1D);
      SET_TexSubImage1D(exec, _mesa_TexSubImage1D);
      SET_UnmapNamedBufferEXT(exec, _mesa_UnmapNamedBufferEXT);
   }
   if (!_mesa_is_no_error_enabled(ctx) && (ctx->API == API_OPENGLES)) {
      SET_PointSizePointerOES(exec, _mesa_PointSizePointerOES);
   }
   if (!_mesa_is_no_error_enabled(ctx) && (ctx->API == API_OPENGL_COMPAT || ctx->API == API_OPENGLES)) {
      SET_ColorPointer(exec, _mesa_ColorPointer);
      SET_NormalPointer(exec, _mesa_NormalPointer);
      SET_TexCoordPointer(exec, _mesa_TexCoordPointer);
      SET_VertexPointer(exec, _mesa_VertexPointer);
   }
   if (!_mesa_is_no_error_enabled(ctx) && (ctx->API == API_OPENGL_COMPAT || ctx->API == API_OPENGL_CORE || (ctx->API == API_OPENGLES2 && ctx->Version >= 31))) {
      SET_FramebufferTexture(exec, _mesa_FramebufferTexture);
      SET_ScissorArrayv(exec, _mesa_ScissorArrayv);
      SET_ScissorIndexed(exec, _mesa_ScissorIndexed);
      SET_ScissorIndexedv(exec, _mesa_ScissorIndexedv);
      SET_ViewportArrayv(exec, _mesa_ViewportArrayv);
      SET_ViewportIndexedf(exec, _mesa_ViewportIndexedf);
      SET_ViewportIndexedfv(exec, _mesa_ViewportIndexedfv);
   }
   if (!_mesa_is_no_error_enabled(ctx) && (ctx->API == API_OPENGL_COMPAT || ctx->API == API_OPENGL_CORE)) {
      SET_BindTextureUnit(exec, _mesa_BindTextureUnit);
      SET_BlitNamedFramebuffer(exec, _mesa_BlitNamedFramebuffer);
      SET_ClearNamedBufferData(exec, _mesa_ClearNamedBufferData);
      SET_ClearNamedBufferSubData(exec, _mesa_ClearNamedBufferSubData);
      SET_CompressedTextureSubImage1D(exec, _mesa_CompressedTextureSubImage1D);
      SET_CompressedTextureSubImage2D(exec, _mesa_CompressedTextureSubImage2D);
      SET_CompressedTextureSubImage3D(exec, _mesa_CompressedTextureSubImage3D);
      SET_CopyNamedBufferSubData(exec, _mesa_CopyNamedBufferSubData);
      SET_CopyTextureSubImage1D(exec, _mesa_CopyTextureSubImage1D);
      SET_CopyTextureSubImage2D(exec, _mesa_CopyTextureSubImage2D);
      SET_CopyTextureSubImage3D(exec, _mesa_CopyTextureSubImage3D);
      SET_CreateBuffers(exec, _mesa_CreateBuffers);
      SET_CreateProgramPipelines(exec, _mesa_CreateProgramPipelines);
      SET_CreateRenderbuffers(exec, _mesa_CreateRenderbuffers);
      SET_CreateSamplers(exec, _mesa_CreateSamplers);
      SET_CreateTextures(exec, _mesa_CreateTextures);
      SET_CreateVertexArrays(exec, _mesa_CreateVertexArrays);
      SET_DepthRangeArrayv(exec, _mesa_DepthRangeArrayv);
      SET_DepthRangeIndexed(exec, _mesa_DepthRangeIndexed);
      SET_DisableVertexArrayAttrib(exec, _mesa_DisableVertexArrayAttrib);
      SET_EnableVertexArrayAttrib(exec, _mesa_EnableVertexArrayAttrib);
      SET_FlushMappedNamedBufferRange(exec, _mesa_FlushMappedNamedBufferRange);
      SET_GenerateTextureMipmap(exec, _mesa_GenerateTextureMipmap);
      SET_MapNamedBuffer(exec, _mesa_MapNamedBuffer);
      SET_MapNamedBufferRange(exec, _mesa_MapNamedBufferRange);
      SET_NamedBufferData(exec, _mesa_NamedBufferData);
      SET_NamedBufferStorage(exec, _mesa_NamedBufferStorage);
      SET_NamedBufferSubData(exec, _mesa_NamedBufferSubData);
      SET_NamedFramebufferDrawBuffer(exec, _mesa_NamedFramebufferDrawBuffer);
      SET_NamedFramebufferDrawBuffers(exec, _mesa_NamedFramebufferDrawBuffers);
      SET_NamedFramebufferReadBuffer(exec, _mesa_NamedFramebufferReadBuffer);
      SET_NamedFramebufferRenderbuffer(exec, _mesa_NamedFramebufferRenderbuffer);
      SET_NamedFramebufferTexture(exec, _mesa_NamedFramebufferTexture);
      SET_NamedFramebufferTextureLayer(exec, _mesa_NamedFramebufferTextureLayer);
      SET_TextureStorage1D(exec, _mesa_TextureStorage1D);
      SET_TextureStorage2D(exec, _mesa_TextureStorage2D);
      SET_TextureStorage3D(exec, _mesa_TextureStorage3D);
      SET_TextureSubImage1D(exec, _mesa_TextureSubImage1D);
      SET_TextureSubImage2D(exec, _mesa_TextureSubImage2D);
      SET_TextureSubImage3D(exec, _mesa_TextureSubImage3D);
      SET_VertexArrayAttribBinding(exec, _mesa_VertexArrayAttribBinding);
      SET_VertexArrayBindingDivisor(exec, _mesa_VertexArrayBindingDivisor);
      SET_VertexArrayElementBuffer(exec, _mesa_VertexArrayElementBuffer);
      SET_VertexArrayVertexBuffer(exec, _mesa_VertexArrayVertexBuffer);
      SET_VertexArrayVertexBuffers(exec, _mesa_VertexArrayVertexBuffers);
      SET_VertexAttribLPointer(exec, _mesa_VertexAttribLPointer);
   }
   if (!_mesa_is_no_error_enabled(ctx) && (ctx->API == API_OPENGL_COMPAT)) {
      SET_EdgeFlagPointer(exec, _mesa_EdgeFlagPointer);
      SET_FogCoordPointer(exec, _mesa_FogCoordPointer);
      SET_IndexPointer(exec, _mesa_IndexPointer);
      SET_SecondaryColorPointer(exec, _mesa_SecondaryColorPointer);
   }
   if ((ctx->API == API_OPENGLES2 && ctx->Version >= 31)) {
      SET_DepthRangeArrayfvOES(exec, _mesa_DepthRangeArrayfvOES);
      SET_DepthRangeIndexedfOES(exec, _mesa_DepthRangeIndexedfOES);
   }
   if (_mesa_is_desktop_gl(ctx)) {
      SET_BeginQueryIndexed(exec, _mesa_BeginQueryIndexed);
      SET_BindBuffersBase(exec, _mesa_BindBuffersBase);
      SET_BindBuffersRange(exec, _mesa_BindBuffersRange);
      SET_BindFramebufferEXT(exec, _mesa_BindFramebufferEXT);
      SET_BindImageTextureEXT(exec, _mesa_BindImageTextureEXT);
      SET_BindMultiTextureEXT(exec, _mesa_BindMultiTextureEXT);
      SET_BindRenderbufferEXT(exec, _mesa_BindRenderbufferEXT);
      SET_BufferPageCommitmentARB(exec, _mesa_BufferPageCommitmentARB);
      SET_CheckNamedFramebufferStatusEXT(exec, _mesa_CheckNamedFramebufferStatusEXT);
      SET_ClampColor(exec, _mesa_ClampColor);
      SET_ClearColorIiEXT(exec, _mesa_ClearColorIiEXT);
      SET_ClearColorIuiEXT(exec, _mesa_ClearColorIuiEXT);
      SET_ClearDepth(exec, _mesa_ClearDepth);
      SET_ClearNamedBufferDataEXT(exec, _mesa_ClearNamedBufferDataEXT);
      SET_ClearNamedBufferSubDataEXT(exec, _mesa_ClearNamedBufferSubDataEXT);
      SET_ClientAttribDefaultEXT(exec, _mesa_ClientAttribDefaultEXT);
      SET_CompileShaderIncludeARB(exec, _mesa_CompileShaderIncludeARB);
      SET_CompressedMultiTexImage1DEXT(exec, _mesa_CompressedMultiTexImage1DEXT);
      SET_CompressedMultiTexImage2DEXT(exec, _mesa_CompressedMultiTexImage2DEXT);
      SET_CompressedMultiTexImage3DEXT(exec, _mesa_CompressedMultiTexImage3DEXT);
      SET_CompressedMultiTexSubImage1DEXT(exec, _mesa_CompressedMultiTexSubImage1DEXT);
      SET_CompressedMultiTexSubImage2DEXT(exec, _mesa_CompressedMultiTexSubImage2DEXT);
      SET_CompressedMultiTexSubImage3DEXT(exec, _mesa_CompressedMultiTexSubImage3DEXT);
      SET_CompressedTextureImage1DEXT(exec, _mesa_CompressedTextureImage1DEXT);
      SET_CompressedTextureImage2DEXT(exec, _mesa_CompressedTextureImage2DEXT);
      SET_CompressedTextureImage3DEXT(exec, _mesa_CompressedTextureImage3DEXT);
      SET_CompressedTextureSubImage1DEXT(exec, _mesa_CompressedTextureSubImage1DEXT);
      SET_CompressedTextureSubImage2DEXT(exec, _mesa_CompressedTextureSubImage2DEXT);
      SET_CompressedTextureSubImage3DEXT(exec, _mesa_CompressedTextureSubImage3DEXT);
      SET_CopyMultiTexImage1DEXT(exec, _mesa_CopyMultiTexImage1DEXT);
      SET_CopyMultiTexImage2DEXT(exec, _mesa_CopyMultiTexImage2DEXT);
      SET_CopyMultiTexSubImage1DEXT(exec, _mesa_CopyMultiTexSubImage1DEXT);
      SET_CopyMultiTexSubImage2DEXT(exec, _mesa_CopyMultiTexSubImage2DEXT);
      SET_CopyMultiTexSubImage3DEXT(exec, _mesa_CopyMultiTexSubImage3DEXT);
      SET_CopyTextureImage1DEXT(exec, _mesa_CopyTextureImage1DEXT);
      SET_CopyTextureImage2DEXT(exec, _mesa_CopyTextureImage2DEXT);
      SET_CopyTextureSubImage1DEXT(exec, _mesa_CopyTextureSubImage1DEXT);
      SET_CopyTextureSubImage2DEXT(exec, _mesa_CopyTextureSubImage2DEXT);
      SET_CopyTextureSubImage3DEXT(exec, _mesa_CopyTextureSubImage3DEXT);
      SET_CreateProgramObjectARB(exec, _mesa_CreateProgramObjectARB);
      SET_DeleteNamedStringARB(exec, _mesa_DeleteNamedStringARB);
      SET_DeleteObjectARB(exec, _mesa_DeleteObjectARB);
      SET_DepthBoundsEXT(exec, _mesa_DepthBoundsEXT);
      SET_DepthRange(exec, _mesa_DepthRange);
      SET_DisableClientStateiEXT(exec, _mesa_DisableClientStateiEXT);
      SET_DisableVertexArrayAttribEXT(exec, _mesa_DisableVertexArrayAttribEXT);
      SET_DisableVertexArrayEXT(exec, _mesa_DisableVertexArrayEXT);
      SET_DrawTransformFeedback(exec, _mesa_DrawTransformFeedback);
      SET_DrawTransformFeedbackInstanced(exec, _mesa_DrawTransformFeedbackInstanced);
      SET_DrawTransformFeedbackStream(exec, _mesa_DrawTransformFeedbackStream);
      SET_DrawTransformFeedbackStreamInstanced(exec, _mesa_DrawTransformFeedbackStreamInstanced);
      SET_EGLImageTargetTextureStorageEXT(exec, _mesa_EGLImageTargetTextureStorageEXT);
      SET_EnableClientStateiEXT(exec, _mesa_EnableClientStateiEXT);
      SET_EnableVertexArrayAttribEXT(exec, _mesa_EnableVertexArrayAttribEXT);
      SET_EnableVertexArrayEXT(exec, _mesa_EnableVertexArrayEXT);
      SET_EndQueryIndexed(exec, _mesa_EndQueryIndexed);
      SET_FlushMappedNamedBufferRangeEXT(exec, _mesa_FlushMappedNamedBufferRangeEXT);
      SET_FramebufferDrawBufferEXT(exec, _mesa_FramebufferDrawBufferEXT);
      SET_FramebufferDrawBuffersEXT(exec, _mesa_FramebufferDrawBuffersEXT);
      SET_FramebufferReadBufferEXT(exec, _mesa_FramebufferReadBufferEXT);
      SET_GenerateMultiTexMipmapEXT(exec, _mesa_GenerateMultiTexMipmapEXT);
      SET_GenerateTextureMipmapEXT(exec, _mesa_GenerateTextureMipmapEXT);
      SET_GetActiveAtomicCounterBufferiv(exec, _mesa_GetActiveAtomicCounterBufferiv);
      SET_GetActiveUniformName(exec, _mesa_GetActiveUniformName);
      SET_GetAttachedObjectsARB(exec, _mesa_GetAttachedObjectsARB);
      SET_GetBufferSubData(exec, _mesa_GetBufferSubData);
      SET_GetCompressedMultiTexImageEXT(exec, _mesa_GetCompressedMultiTexImageEXT);
      SET_GetCompressedTexImage(exec, _mesa_GetCompressedTexImage);
      SET_GetCompressedTextureImageEXT(exec, _mesa_GetCompressedTextureImageEXT);
      SET_GetCompressedTextureSubImage(exec, _mesa_GetCompressedTextureSubImage);
      SET_GetDoublei_v(exec, _mesa_GetDoublei_v);
      SET_GetDoublev(exec, _mesa_GetDoublev);
      SET_GetFramebufferParameterivEXT(exec, _mesa_GetFramebufferParameterivEXT);
      SET_GetHandleARB(exec, _mesa_GetHandleARB);
      SET_GetInfoLogARB(exec, _mesa_GetInfoLogARB);
      SET_GetMultiTexEnvfvEXT(exec, _mesa_GetMultiTexEnvfvEXT);
      SET_GetMultiTexEnvivEXT(exec, _mesa_GetMultiTexEnvivEXT);
      SET_GetMultiTexGendvEXT(exec, _mesa_GetMultiTexGendvEXT);
      SET_GetMultiTexGenfvEXT(exec, _mesa_GetMultiTexGenfvEXT);
      SET_GetMultiTexGenivEXT(exec, _mesa_GetMultiTexGenivEXT);
      SET_GetMultiTexImageEXT(exec, _mesa_GetMultiTexImageEXT);
      SET_GetMultiTexLevelParameterfvEXT(exec, _mesa_GetMultiTexLevelParameterfvEXT);
      SET_GetMultiTexLevelParameterivEXT(exec, _mesa_GetMultiTexLevelParameterivEXT);
      SET_GetMultiTexParameterIivEXT(exec, _mesa_GetMultiTexParameterIivEXT);
      SET_GetMultiTexParameterIuivEXT(exec, _mesa_GetMultiTexParameterIuivEXT);
      SET_GetMultiTexParameterfvEXT(exec, _mesa_GetMultiTexParameterfvEXT);
      SET_GetMultiTexParameterivEXT(exec, _mesa_GetMultiTexParameterivEXT);
      SET_GetNamedBufferParameterivEXT(exec, _mesa_GetNamedBufferParameterivEXT);
      SET_GetNamedBufferPointervEXT(exec, _mesa_GetNamedBufferPointervEXT);
      SET_GetNamedBufferSubDataEXT(exec, _mesa_GetNamedBufferSubDataEXT);
      SET_GetNamedFramebufferAttachmentParameterivEXT(exec, _mesa_GetNamedFramebufferAttachmentParameterivEXT);
      SET_GetNamedFramebufferParameterivEXT(exec, _mesa_GetNamedFramebufferParameterivEXT);
      SET_GetNamedProgramLocalParameterdvEXT(exec, _mesa_GetNamedProgramLocalParameterdvEXT);
      SET_GetNamedProgramLocalParameterfvEXT(exec, _mesa_GetNamedProgramLocalParameterfvEXT);
      SET_GetNamedProgramStringEXT(exec, _mesa_GetNamedProgramStringEXT);
      SET_GetNamedProgramivEXT(exec, _mesa_GetNamedProgramivEXT);
      SET_GetNamedRenderbufferParameterivEXT(exec, _mesa_GetNamedRenderbufferParameterivEXT);
      SET_GetNamedStringARB(exec, _mesa_GetNamedStringARB);
      SET_GetNamedStringivARB(exec, _mesa_GetNamedStringivARB);
      SET_GetObjectParameterfvARB(exec, _mesa_GetObjectParameterfvARB);
      SET_GetObjectParameterivARB(exec, _mesa_GetObjectParameterivARB);
      SET_GetPointerIndexedvEXT(exec, _mesa_GetPointerIndexedvEXT);
      SET_GetQueryIndexediv(exec, _mesa_GetQueryIndexediv);
      SET_GetTexImage(exec, _mesa_GetTexImage);
      SET_GetTextureImageEXT(exec, _mesa_GetTextureImageEXT);
      SET_GetTextureLevelParameterfvEXT(exec, _mesa_GetTextureLevelParameterfvEXT);
      SET_GetTextureLevelParameterivEXT(exec, _mesa_GetTextureLevelParameterivEXT);
      SET_GetTextureParameterIivEXT(exec, _mesa_GetTextureParameterIivEXT);
      SET_GetTextureParameterIuivEXT(exec, _mesa_GetTextureParameterIuivEXT);
      SET_GetTextureParameterfvEXT(exec, _mesa_GetTextureParameterfvEXT);
      SET_GetTextureParameterivEXT(exec, _mesa_GetTextureParameterivEXT);
      SET_GetTextureSubImage(exec, _mesa_GetTextureSubImage);
      SET_GetVertexArrayIntegeri_vEXT(exec, _mesa_GetVertexArrayIntegeri_vEXT);
      SET_GetVertexArrayIntegervEXT(exec, _mesa_GetVertexArrayIntegervEXT);
      SET_GetVertexArrayPointeri_vEXT(exec, _mesa_GetVertexArrayPointeri_vEXT);
      SET_GetVertexArrayPointervEXT(exec, _mesa_GetVertexArrayPointervEXT);
      SET_GetVertexAttribdv(exec, _mesa_GetVertexAttribdv);
      SET_GetnCompressedTexImageARB(exec, _mesa_GetnCompressedTexImageARB);
      SET_GetnPolygonStippleARB(exec, _mesa_GetnPolygonStippleARB);
      SET_GetnTexImageARB(exec, _mesa_GetnTexImageARB);
      SET_GetnUniformdvARB(exec, _mesa_GetnUniformdvARB);
      SET_IsNamedStringARB(exec, _mesa_IsNamedStringARB);
      SET_MapNamedBufferEXT(exec, _mesa_MapNamedBufferEXT);
      SET_MapNamedBufferRangeEXT(exec, _mesa_MapNamedBufferRangeEXT);
      SET_MatrixFrustumEXT(exec, _mesa_MatrixFrustumEXT);
      SET_MatrixLoadIdentityEXT(exec, _mesa_MatrixLoadIdentityEXT);
      SET_MatrixLoadTransposedEXT(exec, _mesa_MatrixLoadTransposedEXT);
      SET_MatrixLoadTransposefEXT(exec, _mesa_MatrixLoadTransposefEXT);
      SET_MatrixLoaddEXT(exec, _mesa_MatrixLoaddEXT);
      SET_MatrixLoadfEXT(exec, _mesa_MatrixLoadfEXT);
      SET_MatrixMultTransposedEXT(exec, _mesa_MatrixMultTransposedEXT);
      SET_MatrixMultTransposefEXT(exec, _mesa_MatrixMultTransposefEXT);
      SET_MatrixMultdEXT(exec, _mesa_MatrixMultdEXT);
      SET_MatrixMultfEXT(exec, _mesa_MatrixMultfEXT);
      SET_MatrixOrthoEXT(exec, _mesa_MatrixOrthoEXT);
      SET_MatrixPopEXT(exec, _mesa_MatrixPopEXT);
      SET_MatrixPushEXT(exec, _mesa_MatrixPushEXT);
      SET_MatrixRotatedEXT(exec, _mesa_MatrixRotatedEXT);
      SET_MatrixRotatefEXT(exec, _mesa_MatrixRotatefEXT);
      SET_MatrixScaledEXT(exec, _mesa_MatrixScaledEXT);
      SET_MatrixScalefEXT(exec, _mesa_MatrixScalefEXT);
      SET_MatrixTranslatedEXT(exec, _mesa_MatrixTranslatedEXT);
      SET_MatrixTranslatefEXT(exec, _mesa_MatrixTranslatefEXT);
      SET_MultiDrawArraysIndirect(exec, _mesa_MultiDrawArraysIndirect);
      SET_MultiDrawArraysIndirectCountARB(exec, _mesa_MultiDrawArraysIndirectCountARB);
      SET_MultiDrawElementsIndirect(exec, _mesa_MultiDrawElementsIndirect);
      SET_MultiDrawElementsIndirectCountARB(exec, _mesa_MultiDrawElementsIndirectCountARB);
      SET_MultiModeDrawArraysIBM(exec, _mesa_MultiModeDrawArraysIBM);
      SET_MultiModeDrawElementsIBM(exec, _mesa_MultiModeDrawElementsIBM);
      SET_MultiTexBufferEXT(exec, _mesa_MultiTexBufferEXT);
      SET_MultiTexCoordPointerEXT(exec, _mesa_MultiTexCoordPointerEXT);
      SET_MultiTexEnvfEXT(exec, _mesa_MultiTexEnvfEXT);
      SET_MultiTexEnvfvEXT(exec, _mesa_MultiTexEnvfvEXT);
      SET_MultiTexEnviEXT(exec, _mesa_MultiTexEnviEXT);
      SET_MultiTexEnvivEXT(exec, _mesa_MultiTexEnvivEXT);
      SET_MultiTexGendEXT(exec, _mesa_MultiTexGendEXT);
      SET_MultiTexGendvEXT(exec, _mesa_MultiTexGendvEXT);
      SET_MultiTexGenfEXT(exec, _mesa_MultiTexGenfEXT);
      SET_MultiTexGenfvEXT(exec, _mesa_MultiTexGenfvEXT);
      SET_MultiTexGeniEXT(exec, _mesa_MultiTexGeniEXT);
      SET_MultiTexGenivEXT(exec, _mesa_MultiTexGenivEXT);
      SET_MultiTexImage1DEXT(exec, _mesa_MultiTexImage1DEXT);
      SET_MultiTexImage2DEXT(exec, _mesa_MultiTexImage2DEXT);
      SET_MultiTexImage3DEXT(exec, _mesa_MultiTexImage3DEXT);
      SET_MultiTexParameterIivEXT(exec, _mesa_MultiTexParameterIivEXT);
      SET_MultiTexParameterIuivEXT(exec, _mesa_MultiTexParameterIuivEXT);
      SET_MultiTexParameterfEXT(exec, _mesa_MultiTexParameterfEXT);
      SET_MultiTexParameterfvEXT(exec, _mesa_MultiTexParameterfvEXT);
      SET_MultiTexParameteriEXT(exec, _mesa_MultiTexParameteriEXT);
      SET_MultiTexParameterivEXT(exec, _mesa_MultiTexParameterivEXT);
      SET_MultiTexSubImage1DEXT(exec, _mesa_MultiTexSubImage1DEXT);
      SET_MultiTexSubImage2DEXT(exec, _mesa_MultiTexSubImage2DEXT);
      SET_MultiTexSubImage3DEXT(exec, _mesa_MultiTexSubImage3DEXT);
      SET_NamedBufferDataEXT(exec, _mesa_NamedBufferDataEXT);
      SET_NamedBufferPageCommitmentARB(exec, _mesa_NamedBufferPageCommitmentARB);
      SET_NamedBufferPageCommitmentEXT(exec, _mesa_NamedBufferPageCommitmentEXT);
      SET_NamedBufferStorageEXT(exec, _mesa_NamedBufferStorageEXT);
      SET_NamedBufferSubDataEXT(exec, _mesa_NamedBufferSubDataEXT);
      SET_NamedCopyBufferSubDataEXT(exec, _mesa_NamedCopyBufferSubDataEXT);
      SET_NamedFramebufferParameteriEXT(exec, _mesa_NamedFramebufferParameteriEXT);
      SET_NamedFramebufferRenderbufferEXT(exec, _mesa_NamedFramebufferRenderbufferEXT);
      SET_NamedFramebufferTexture1DEXT(exec, _mesa_NamedFramebufferTexture1DEXT);
      SET_NamedFramebufferTexture2DEXT(exec, _mesa_NamedFramebufferTexture2DEXT);
      SET_NamedFramebufferTexture3DEXT(exec, _mesa_NamedFramebufferTexture3DEXT);
      SET_NamedProgramLocalParameter4dEXT(exec, _mesa_NamedProgramLocalParameter4dEXT);
      SET_NamedProgramLocalParameter4dvEXT(exec, _mesa_NamedProgramLocalParameter4dvEXT);
      SET_NamedProgramLocalParameter4fEXT(exec, _mesa_NamedProgramLocalParameter4fEXT);
      SET_NamedProgramLocalParameter4fvEXT(exec, _mesa_NamedProgramLocalParameter4fvEXT);
      SET_NamedProgramLocalParameters4fvEXT(exec, _mesa_NamedProgramLocalParameters4fvEXT);
      SET_NamedProgramStringEXT(exec, _mesa_NamedProgramStringEXT);
      SET_NamedRenderbufferStorageEXT(exec, _mesa_NamedRenderbufferStorageEXT);
      SET_NamedRenderbufferStorageMultisampleEXT(exec, _mesa_NamedRenderbufferStorageMultisampleEXT);
      SET_NamedStringARB(exec, _mesa_NamedStringARB);
      SET_PatchParameterfv(exec, _mesa_PatchParameterfv);
      SET_PointParameteri(exec, _mesa_PointParameteri);
      SET_PointParameteriv(exec, _mesa_PointParameteriv);
      SET_ProgramUniform1d(exec, _mesa_ProgramUniform1d);
      SET_ProgramUniform1dv(exec, _mesa_ProgramUniform1dv);
      SET_ProgramUniform2d(exec, _mesa_ProgramUniform2d);
      SET_ProgramUniform2dv(exec, _mesa_ProgramUniform2dv);
      SET_ProgramUniform3d(exec, _mesa_ProgramUniform3d);
      SET_ProgramUniform3dv(exec, _mesa_ProgramUniform3dv);
      SET_ProgramUniform4d(exec, _mesa_ProgramUniform4d);
      SET_ProgramUniform4dv(exec, _mesa_ProgramUniform4dv);
      SET_ProgramUniformHandleui64ARB(exec, _mesa_ProgramUniformHandleui64ARB);
      SET_ProgramUniformHandleui64vARB(exec, _mesa_ProgramUniformHandleui64vARB);
      SET_ProgramUniformMatrix2dv(exec, _mesa_ProgramUniformMatrix2dv);
      SET_ProgramUniformMatrix2x3dv(exec, _mesa_ProgramUniformMatrix2x3dv);
      SET_ProgramUniformMatrix2x4dv(exec, _mesa_ProgramUniformMatrix2x4dv);
      SET_ProgramUniformMatrix3dv(exec, _mesa_ProgramUniformMatrix3dv);
      SET_ProgramUniformMatrix3x2dv(exec, _mesa_ProgramUniformMatrix3x2dv);
      SET_ProgramUniformMatrix3x4dv(exec, _mesa_ProgramUniformMatrix3x4dv);
      SET_ProgramUniformMatrix4dv(exec, _mesa_ProgramUniformMatrix4dv);
      SET_ProgramUniformMatrix4x2dv(exec, _mesa_ProgramUniformMatrix4x2dv);
      SET_ProgramUniformMatrix4x3dv(exec, _mesa_ProgramUniformMatrix4x3dv);
      SET_ProvokingVertex(exec, _mesa_ProvokingVertex);
      SET_PushClientAttribDefaultEXT(exec, _mesa_PushClientAttribDefaultEXT);
      SET_SpecializeShaderARB(exec, _mesa_SpecializeShaderARB);
      SET_StringMarkerGREMEDY(exec, _mesa_StringMarkerGREMEDY);
      SET_TexImage2DMultisample(exec, _mesa_TexImage2DMultisample);
      SET_TexImage3DMultisample(exec, _mesa_TexImage3DMultisample);
      SET_TexPageCommitmentARB(exec, _mesa_TexPageCommitmentARB);
      SET_TexStorageMem1DEXT(exec, _mesa_TexStorageMem1DEXT);
      SET_TextureBarrierNV(exec, _mesa_TextureBarrierNV);
      SET_TextureBufferEXT(exec, _mesa_TextureBufferEXT);
      SET_TextureBufferRangeEXT(exec, _mesa_TextureBufferRangeEXT);
      SET_TextureImage1DEXT(exec, _mesa_TextureImage1DEXT);
      SET_TextureImage2DEXT(exec, _mesa_TextureImage2DEXT);
      SET_TextureImage3DEXT(exec, _mesa_TextureImage3DEXT);
      SET_TexturePageCommitmentEXT(exec, _mesa_TexturePageCommitmentEXT);
      SET_TextureParameterIivEXT(exec, _mesa_TextureParameterIivEXT);
      SET_TextureParameterIuivEXT(exec, _mesa_TextureParameterIuivEXT);
      SET_TextureParameterfEXT(exec, _mesa_TextureParameterfEXT);
      SET_TextureParameterfvEXT(exec, _mesa_TextureParameterfvEXT);
      SET_TextureParameteriEXT(exec, _mesa_TextureParameteriEXT);
      SET_TextureParameterivEXT(exec, _mesa_TextureParameterivEXT);
      SET_TextureStorage1DEXT(exec, _mesa_TextureStorage1DEXT);
      SET_TextureStorage2DEXT(exec, _mesa_TextureStorage2DEXT);
      SET_TextureStorage2DMultisampleEXT(exec, _mesa_TextureStorage2DMultisampleEXT);
      SET_TextureStorage3DEXT(exec, _mesa_TextureStorage3DEXT);
      SET_TextureStorage3DMultisampleEXT(exec, _mesa_TextureStorage3DMultisampleEXT);
      SET_TextureStorageMem1DEXT(exec, _mesa_TextureStorageMem1DEXT);
      SET_TextureSubImage1DEXT(exec, _mesa_TextureSubImage1DEXT);
      SET_TextureSubImage2DEXT(exec, _mesa_TextureSubImage2DEXT);
      SET_TextureSubImage3DEXT(exec, _mesa_TextureSubImage3DEXT);
      SET_UniformHandleui64ARB(exec, _mesa_UniformHandleui64ARB);
      SET_UniformHandleui64vARB(exec, _mesa_UniformHandleui64vARB);
      SET_VDPAUFiniNV(exec, _mesa_VDPAUFiniNV);
      SET_VDPAUGetSurfaceivNV(exec, _mesa_VDPAUGetSurfaceivNV);
      SET_VDPAUInitNV(exec, _mesa_VDPAUInitNV);
      SET_VDPAUIsSurfaceNV(exec, _mesa_VDPAUIsSurfaceNV);
      SET_VDPAUMapSurfacesNV(exec, _mesa_VDPAUMapSurfacesNV);
      SET_VDPAURegisterOutputSurfaceNV(exec, _mesa_VDPAURegisterOutputSurfaceNV);
      SET_VDPAURegisterVideoSurfaceNV(exec, _mesa_VDPAURegisterVideoSurfaceNV);
      SET_VDPAUSurfaceAccessNV(exec, _mesa_VDPAUSurfaceAccessNV);
      SET_VDPAUUnmapSurfacesNV(exec, _mesa_VDPAUUnmapSurfacesNV);
      SET_VDPAUUnregisterSurfaceNV(exec, _mesa_VDPAUUnregisterSurfaceNV);
      SET_VertexArrayBindVertexBufferEXT(exec, _mesa_VertexArrayBindVertexBufferEXT);
      SET_VertexArrayColorOffsetEXT(exec, _mesa_VertexArrayColorOffsetEXT);
      SET_VertexArrayEdgeFlagOffsetEXT(exec, _mesa_VertexArrayEdgeFlagOffsetEXT);
      SET_VertexArrayFogCoordOffsetEXT(exec, _mesa_VertexArrayFogCoordOffsetEXT);
      SET_VertexArrayIndexOffsetEXT(exec, _mesa_VertexArrayIndexOffsetEXT);
      SET_VertexArrayMultiTexCoordOffsetEXT(exec, _mesa_VertexArrayMultiTexCoordOffsetEXT);
      SET_VertexArrayNormalOffsetEXT(exec, _mesa_VertexArrayNormalOffsetEXT);
      SET_VertexArraySecondaryColorOffsetEXT(exec, _mesa_VertexArraySecondaryColorOffsetEXT);
      SET_VertexArrayTexCoordOffsetEXT(exec, _mesa_VertexArrayTexCoordOffsetEXT);
      SET_VertexArrayVertexAttribBindingEXT(exec, _mesa_VertexArrayVertexAttribBindingEXT);
      SET_VertexArrayVertexAttribDivisorEXT(exec, _mesa_VertexArrayVertexAttribDivisorEXT);
      SET_VertexArrayVertexAttribFormatEXT(exec, _mesa_VertexArrayVertexAttribFormatEXT);
      SET_VertexArrayVertexAttribIFormatEXT(exec, _mesa_VertexArrayVertexAttribIFormatEXT);
      SET_VertexArrayVertexAttribIOffsetEXT(exec, _mesa_VertexArrayVertexAttribIOffsetEXT);
      SET_VertexArrayVertexAttribLFormatEXT(exec, _mesa_VertexArrayVertexAttribLFormatEXT);
      SET_VertexArrayVertexAttribLOffsetEXT(exec, _mesa_VertexArrayVertexAttribLOffsetEXT);
      SET_VertexArrayVertexAttribOffsetEXT(exec, _mesa_VertexArrayVertexAttribOffsetEXT);
      SET_VertexArrayVertexBindingDivisorEXT(exec, _mesa_VertexArrayVertexBindingDivisorEXT);
      SET_VertexArrayVertexOffsetEXT(exec, _mesa_VertexArrayVertexOffsetEXT);
      SET_VertexAttribLFormat(exec, _mesa_VertexAttribLFormat);
   }
   if (_mesa_is_desktop_gl(ctx) || (ctx->API == API_OPENGLES2 && ctx->Version >= 30)) {
      SET_BindBufferBase(exec, _mesa_BindBufferBase);
      SET_ColorMaski(exec, _mesa_ColorMaski);
      SET_DeleteTransformFeedbacks(exec, _mesa_DeleteTransformFeedbacks);
      SET_Disablei(exec, _mesa_Disablei);
      SET_DrawArraysInstancedBaseInstance(exec, _mesa_DrawArraysInstancedBaseInstance);
      SET_DrawElementsInstancedBaseInstance(exec, _mesa_DrawElementsInstancedBaseInstance);
      SET_DrawElementsInstancedBaseVertex(exec, _mesa_DrawElementsInstancedBaseVertex);
      SET_DrawElementsInstancedBaseVertexBaseInstance(exec, _mesa_DrawElementsInstancedBaseVertexBaseInstance);
      SET_DrawRangeElements(exec, _mesa_DrawRangeElements);
      SET_DrawRangeElementsBaseVertex(exec, _mesa_DrawRangeElementsBaseVertex);
      SET_EGLImageTargetTexStorageEXT(exec, _mesa_EGLImageTargetTexStorageEXT);
      SET_Enablei(exec, _mesa_Enablei);
      SET_GenTransformFeedbacks(exec, _mesa_GenTransformFeedbacks);
      SET_GetActiveUniformBlockName(exec, _mesa_GetActiveUniformBlockName);
      SET_GetActiveUniformBlockiv(exec, _mesa_GetActiveUniformBlockiv);
      SET_GetActiveUniformsiv(exec, _mesa_GetActiveUniformsiv);
      SET_GetBufferParameteri64v(exec, _mesa_GetBufferParameteri64v);
      SET_GetFragDataIndex(exec, _mesa_GetFragDataIndex);
      SET_GetFragDataLocation(exec, _mesa_GetFragDataLocation);
      SET_GetInteger64i_v(exec, _mesa_GetInteger64i_v);
      SET_GetIntegeri_v(exec, _mesa_GetIntegeri_v);
      SET_GetInternalformati64v(exec, _mesa_GetInternalformati64v);
      SET_GetInternalformativ(exec, _mesa_GetInternalformativ);
      SET_GetSamplerParameterIiv(exec, _mesa_GetSamplerParameterIiv);
      SET_GetSamplerParameterIuiv(exec, _mesa_GetSamplerParameterIuiv);
      SET_GetSamplerParameterfv(exec, _mesa_GetSamplerParameterfv);
      SET_GetSamplerParameteriv(exec, _mesa_GetSamplerParameteriv);
      SET_GetStringi(exec, _mesa_GetStringi);
      SET_GetSynciv(exec, _mesa_GetSynciv);
      SET_GetTexParameterIiv(exec, _mesa_GetTexParameterIiv);
      SET_GetTexParameterIuiv(exec, _mesa_GetTexParameterIuiv);
      SET_GetTransformFeedbackVarying(exec, _mesa_GetTransformFeedbackVarying);
      SET_GetUniformBlockIndex(exec, _mesa_GetUniformBlockIndex);
      SET_GetUniformIndices(exec, _mesa_GetUniformIndices);
      SET_GetUniformuiv(exec, _mesa_GetUniformuiv);
      SET_GetVertexAttribIiv(exec, _mesa_GetVertexAttribIiv);
      SET_GetVertexAttribIuiv(exec, _mesa_GetVertexAttribIuiv);
      SET_IsEnabledi(exec, _mesa_IsEnabledi);
      SET_IsSampler(exec, _mesa_IsSampler);
      SET_IsSync(exec, _mesa_IsSync);
      SET_IsTransformFeedback(exec, _mesa_IsTransformFeedback);
      SET_NamedRenderbufferStorageMultisampleAdvancedAMD(exec, _mesa_NamedRenderbufferStorageMultisampleAdvancedAMD);
      SET_ProgramUniform1ui(exec, _mesa_ProgramUniform1ui);
      SET_ProgramUniform1uiv(exec, _mesa_ProgramUniform1uiv);
      SET_ProgramUniform2ui(exec, _mesa_ProgramUniform2ui);
      SET_ProgramUniform2uiv(exec, _mesa_ProgramUniform2uiv);
      SET_ProgramUniform3ui(exec, _mesa_ProgramUniform3ui);
      SET_ProgramUniform3uiv(exec, _mesa_ProgramUniform3uiv);
      SET_ProgramUniform4ui(exec, _mesa_ProgramUniform4ui);
      SET_ProgramUniform4uiv(exec, _mesa_ProgramUniform4uiv);
      SET_RenderbufferStorageMultisampleAdvancedAMD(exec, _mesa_RenderbufferStorageMultisampleAdvancedAMD);
      SET_SamplerParameterIiv(exec, _mesa_SamplerParameterIiv);
      SET_SamplerParameterIuiv(exec, _mesa_SamplerParameterIuiv);
      SET_SamplerParameterf(exec, _mesa_SamplerParameterf);
      SET_SamplerParameterfv(exec, _mesa_SamplerParameterfv);
      SET_SamplerParameteri(exec, _mesa_SamplerParameteri);
      SET_SamplerParameteriv(exec, _mesa_SamplerParameteriv);
      SET_TexParameterIiv(exec, _mesa_TexParameterIiv);
      SET_TexParameterIuiv(exec, _mesa_TexParameterIuiv);
      SET_Uniform1ui(exec, _mesa_Uniform1ui);
      SET_Uniform1uiv(exec, _mesa_Uniform1uiv);
      SET_Uniform2ui(exec, _mesa_Uniform2ui);
      SET_Uniform2uiv(exec, _mesa_Uniform2uiv);
      SET_Uniform3ui(exec, _mesa_Uniform3ui);
      SET_Uniform3uiv(exec, _mesa_Uniform3uiv);
      SET_Uniform4ui(exec, _mesa_Uniform4ui);
      SET_Uniform4uiv(exec, _mesa_Uniform4uiv);
      SET_UniformMatrix2x3fv(exec, _mesa_UniformMatrix2x3fv);
      SET_UniformMatrix2x4fv(exec, _mesa_UniformMatrix2x4fv);
      SET_UniformMatrix3x2fv(exec, _mesa_UniformMatrix3x2fv);
      SET_UniformMatrix3x4fv(exec, _mesa_UniformMatrix3x4fv);
      SET_UniformMatrix4x2fv(exec, _mesa_UniformMatrix4x2fv);
      SET_UniformMatrix4x3fv(exec, _mesa_UniformMatrix4x3fv);
      SET_WindowRectanglesEXT(exec, _mesa_WindowRectanglesEXT);
   }
   if (_mesa_is_desktop_gl(ctx) || (ctx->API == API_OPENGLES2 && ctx->Version >= 31)) {
      SET_ClearTexImage(exec, _mesa_ClearTexImage);
      SET_ClearTexSubImage(exec, _mesa_ClearTexSubImage);
      SET_DrawArraysIndirect(exec, _mesa_DrawArraysIndirect);
      SET_DrawElementsIndirect(exec, _mesa_DrawElementsIndirect);
      SET_EvaluateDepthValuesARB(exec, _mesa_EvaluateDepthValuesARB);
      SET_GetBooleani_v(exec, _mesa_GetBooleani_v);
      SET_GetFloati_v(exec, _mesa_GetFloati_v);
      SET_GetMultisamplefv(exec, _mesa_GetMultisamplefv);
      SET_GetProgramInterfaceiv(exec, _mesa_GetProgramInterfaceiv);
      SET_GetProgramResourceIndex(exec, _mesa_GetProgramResourceIndex);
      SET_GetProgramResourceLocation(exec, _mesa_GetProgramResourceLocation);
      SET_GetProgramResourceLocationIndex(exec, _mesa_GetProgramResourceLocationIndex);
      SET_GetProgramResourceName(exec, _mesa_GetProgramResourceName);
      SET_GetProgramResourceiv(exec, _mesa_GetProgramResourceiv);
      SET_GetTexLevelParameterfv(exec, _mesa_GetTexLevelParameterfv);
      SET_GetTexLevelParameteriv(exec, _mesa_GetTexLevelParameteriv);
      SET_MemoryBarrier(exec, _mesa_MemoryBarrier);
      SET_PrimitiveBoundingBox(exec, _mesa_PrimitiveBoundingBox);
      SET_TexStorage2DMultisample(exec, _mesa_TexStorage2DMultisample);
      SET_TexStorage3DMultisample(exec, _mesa_TexStorage3DMultisample);
      SET_VertexAttribFormat(exec, _mesa_VertexAttribFormat);
      SET_VertexAttribIFormat(exec, _mesa_VertexAttribIFormat);
   }
   if (_mesa_is_desktop_gl(ctx) || (ctx->API == API_OPENGLES2 && ctx->Version >= 32)) {
      SET_CreateMemoryObjectsEXT(exec, _mesa_CreateMemoryObjectsEXT);
      SET_DeleteMemoryObjectsEXT(exec, _mesa_DeleteMemoryObjectsEXT);
      SET_DeleteSemaphoresEXT(exec, _mesa_DeleteSemaphoresEXT);
      SET_GenSemaphoresEXT(exec, _mesa_GenSemaphoresEXT);
      SET_GetMemoryObjectParameterivEXT(exec, _mesa_GetMemoryObjectParameterivEXT);
      SET_GetSemaphoreParameterui64vEXT(exec, _mesa_GetSemaphoreParameterui64vEXT);
      SET_GetUnsignedBytei_vEXT(exec, _mesa_GetUnsignedBytei_vEXT);
      SET_GetUnsignedBytevEXT(exec, _mesa_GetUnsignedBytevEXT);
      SET_ImportMemoryFdEXT(exec, _mesa_ImportMemoryFdEXT);
      SET_ImportMemoryWin32HandleEXT(exec, _mesa_ImportMemoryWin32HandleEXT);
      SET_ImportMemoryWin32NameEXT(exec, _mesa_ImportMemoryWin32NameEXT);
      SET_ImportSemaphoreFdEXT(exec, _mesa_ImportSemaphoreFdEXT);
      SET_ImportSemaphoreWin32HandleEXT(exec, _mesa_ImportSemaphoreWin32HandleEXT);
      SET_ImportSemaphoreWin32NameEXT(exec, _mesa_ImportSemaphoreWin32NameEXT);
      SET_IsMemoryObjectEXT(exec, _mesa_IsMemoryObjectEXT);
      SET_IsSemaphoreEXT(exec, _mesa_IsSemaphoreEXT);
      SET_MemoryObjectParameterivEXT(exec, _mesa_MemoryObjectParameterivEXT);
      SET_SemaphoreParameterui64vEXT(exec, _mesa_SemaphoreParameterui64vEXT);
      SET_SignalSemaphoreEXT(exec, _mesa_SignalSemaphoreEXT);
      SET_TexStorageMem2DEXT(exec, _mesa_TexStorageMem2DEXT);
      SET_TexStorageMem2DMultisampleEXT(exec, _mesa_TexStorageMem2DMultisampleEXT);
      SET_TexStorageMem3DEXT(exec, _mesa_TexStorageMem3DEXT);
      SET_TexStorageMem3DMultisampleEXT(exec, _mesa_TexStorageMem3DMultisampleEXT);
      SET_TextureStorageMem2DEXT(exec, _mesa_TextureStorageMem2DEXT);
      SET_TextureStorageMem2DMultisampleEXT(exec, _mesa_TextureStorageMem2DMultisampleEXT);
      SET_TextureStorageMem3DEXT(exec, _mesa_TextureStorageMem3DEXT);
      SET_TextureStorageMem3DMultisampleEXT(exec, _mesa_TextureStorageMem3DMultisampleEXT);
      SET_WaitSemaphoreEXT(exec, _mesa_WaitSemaphoreEXT);
   }
   if (_mesa_is_desktop_gl(ctx) || ctx->API == API_OPENGLES) {
      SET_PointParameterf(exec, _mesa_PointParameterf);
      SET_PointParameterfv(exec, _mesa_PointParameterfv);
   }
   if (_mesa_is_desktop_gl(ctx) || ctx->API == API_OPENGLES || ctx->API == API_OPENGLES2) {
      SET_BindFramebuffer(exec, _mesa_BindFramebuffer);
      SET_BindRenderbuffer(exec, _mesa_BindRenderbuffer);
      SET_BlendEquation(exec, _mesa_BlendEquation);
      SET_ClearColor(exec, _mesa_ClearColor);
      SET_ClearDepthf(exec, _mesa_ClearDepthf);
      SET_ClearStencil(exec, _mesa_ClearStencil);
      SET_ColorMask(exec, _mesa_ColorMask);
      SET_DebugMessageCallback(exec, _mesa_DebugMessageCallback);
      SET_DebugMessageControl(exec, _mesa_DebugMessageControl);
      SET_DebugMessageInsert(exec, _mesa_DebugMessageInsert);
      SET_DeleteFramebuffers(exec, _mesa_DeleteFramebuffers);
      SET_DeleteRenderbuffers(exec, _mesa_DeleteRenderbuffers);
      SET_DepthMask(exec, _mesa_DepthMask);
      SET_DepthRangef(exec, _mesa_DepthRangef);
      SET_Disable(exec, _mesa_Disable);
      SET_DrawArrays(exec, _mesa_DrawArrays);
      SET_DrawElements(exec, _mesa_DrawElements);
      SET_EGLImageTargetRenderbufferStorageOES(exec, _mesa_EGLImageTargetRenderbufferStorageOES);
      SET_EGLImageTargetTexture2DOES(exec, _mesa_EGLImageTargetTexture2DOES);
      SET_Enable(exec, _mesa_Enable);
      SET_Finish(exec, _mesa_Finish);
      SET_Flush(exec, _mesa_Flush);
      SET_GenFramebuffers(exec, _mesa_GenFramebuffers);
      SET_GetBooleanv(exec, _mesa_GetBooleanv);
      SET_GetBufferParameteriv(exec, _mesa_GetBufferParameteriv);
      SET_GetBufferPointerv(exec, _mesa_GetBufferPointerv);
      SET_GetDebugMessageLog(exec, _mesa_GetDebugMessageLog);
      SET_GetError(exec, _mesa_GetError);
      SET_GetFloatv(exec, _mesa_GetFloatv);
      SET_GetFramebufferAttachmentParameteriv(exec, _mesa_GetFramebufferAttachmentParameteriv);
      SET_GetIntegerv(exec, _mesa_GetIntegerv);
      SET_GetObjectLabel(exec, _mesa_GetObjectLabel);
      SET_GetObjectPtrLabel(exec, _mesa_GetObjectPtrLabel);
      SET_GetPointerv(exec, _mesa_GetPointerv);
      SET_GetRenderbufferParameteriv(exec, _mesa_GetRenderbufferParameteriv);
      SET_GetString(exec, _mesa_GetString);
      SET_GetTexParameterfv(exec, _mesa_GetTexParameterfv);
      SET_GetTexParameteriv(exec, _mesa_GetTexParameteriv);
      SET_Hint(exec, _mesa_Hint);
      SET_InternalSetError(exec, _mesa_InternalSetError);
      SET_IsBuffer(exec, _mesa_IsBuffer);
      SET_IsEnabled(exec, _mesa_IsEnabled);
      SET_IsFramebuffer(exec, _mesa_IsFramebuffer);
      SET_IsRenderbuffer(exec, _mesa_IsRenderbuffer);
      SET_IsTexture(exec, _mesa_IsTexture);
      SET_MultiDrawArrays(exec, _mesa_MultiDrawArrays);
      SET_MultiDrawElementsEXT(exec, _mesa_MultiDrawElementsEXT);
      SET_ObjectLabel(exec, _mesa_ObjectLabel);
      SET_ObjectPtrLabel(exec, _mesa_ObjectPtrLabel);
      SET_PolygonOffset(exec, _mesa_PolygonOffset);
      SET_PolygonOffsetClampEXT(exec, _mesa_PolygonOffsetClampEXT);
      SET_PopDebugGroup(exec, _mesa_PopDebugGroup);
      SET_PushDebugGroup(exec, _mesa_PushDebugGroup);
      SET_RenderbufferStorage(exec, _mesa_RenderbufferStorage);
      SET_SampleCoverage(exec, _mesa_SampleCoverage);
      SET_StencilMask(exec, _mesa_StencilMask);
      SET_TexParameterf(exec, _mesa_TexParameterf);
      SET_TexParameterfv(exec, _mesa_TexParameterfv);
      SET_TexParameteri(exec, _mesa_TexParameteri);
      SET_TexParameteriv(exec, _mesa_TexParameteriv);
   }
   if (_mesa_is_desktop_gl(ctx) || ctx->API == API_OPENGLES2) {
      SET_BeginPerfMonitorAMD(exec, _mesa_BeginPerfMonitorAMD);
      SET_BeginPerfQueryINTEL(exec, _mesa_BeginPerfQueryINTEL);
      SET_BeginQuery(exec, _mesa_BeginQuery);
      SET_BlendBarrier(exec, _mesa_BlendBarrier);
      SET_BlendColor(exec, _mesa_BlendColor);
      SET_CompileShader(exec, _mesa_CompileShader);
      SET_CreatePerfQueryINTEL(exec, _mesa_CreatePerfQueryINTEL);
      SET_CreateProgram(exec, _mesa_CreateProgram);
      SET_CreateShaderProgramv(exec, _mesa_CreateShaderProgramv);
      SET_DeletePerfMonitorsAMD(exec, _mesa_DeletePerfMonitorsAMD);
      SET_DeletePerfQueryINTEL(exec, _mesa_DeletePerfQueryINTEL);
      SET_DeleteProgram(exec, _mesa_DeleteProgram);
      SET_DeleteProgramPipelines(exec, _mesa_DeleteProgramPipelines);
      SET_DeleteQueries(exec, _mesa_DeleteQueries);
      SET_DeleteShader(exec, _mesa_DeleteShader);
      SET_DrawArraysInstancedARB(exec, _mesa_DrawArraysInstancedARB);
      SET_DrawElementsBaseVertex(exec, _mesa_DrawElementsBaseVertex);
      SET_DrawElementsInstancedARB(exec, _mesa_DrawElementsInstancedARB);
      SET_EndPerfMonitorAMD(exec, _mesa_EndPerfMonitorAMD);
      SET_EndPerfQueryINTEL(exec, _mesa_EndPerfQueryINTEL);
      SET_EndQuery(exec, _mesa_EndQuery);
      SET_FramebufferFetchBarrierEXT(exec, _mesa_FramebufferFetchBarrierEXT);
      SET_GenPerfMonitorsAMD(exec, _mesa_GenPerfMonitorsAMD);
      SET_GenQueries(exec, _mesa_GenQueries);
      SET_GetActiveAttrib(exec, _mesa_GetActiveAttrib);
      SET_GetActiveUniform(exec, _mesa_GetActiveUniform);
      SET_GetAttachedShaders(exec, _mesa_GetAttachedShaders);
      SET_GetAttribLocation(exec, _mesa_GetAttribLocation);
      SET_GetFirstPerfQueryIdINTEL(exec, _mesa_GetFirstPerfQueryIdINTEL);
      SET_GetGraphicsResetStatusARB(exec, _mesa_GetGraphicsResetStatusARB);
      SET_GetInteger64v(exec, _mesa_GetInteger64v);
      SET_GetNextPerfQueryIdINTEL(exec, _mesa_GetNextPerfQueryIdINTEL);
      SET_GetPerfCounterInfoINTEL(exec, _mesa_GetPerfCounterInfoINTEL);
      SET_GetPerfMonitorCounterDataAMD(exec, _mesa_GetPerfMonitorCounterDataAMD);
      SET_GetPerfMonitorCounterInfoAMD(exec, _mesa_GetPerfMonitorCounterInfoAMD);
      SET_GetPerfMonitorCounterStringAMD(exec, _mesa_GetPerfMonitorCounterStringAMD);
      SET_GetPerfMonitorCountersAMD(exec, _mesa_GetPerfMonitorCountersAMD);
      SET_GetPerfMonitorGroupStringAMD(exec, _mesa_GetPerfMonitorGroupStringAMD);
      SET_GetPerfMonitorGroupsAMD(exec, _mesa_GetPerfMonitorGroupsAMD);
      SET_GetPerfQueryDataINTEL(exec, _mesa_GetPerfQueryDataINTEL);
      SET_GetPerfQueryIdByNameINTEL(exec, _mesa_GetPerfQueryIdByNameINTEL);
      SET_GetPerfQueryInfoINTEL(exec, _mesa_GetPerfQueryInfoINTEL);
      SET_GetProgramBinary(exec, _mesa_GetProgramBinary);
      SET_GetProgramInfoLog(exec, _mesa_GetProgramInfoLog);
      SET_GetProgramPipelineInfoLog(exec, _mesa_GetProgramPipelineInfoLog);
      SET_GetProgramPipelineiv(exec, _mesa_GetProgramPipelineiv);
      SET_GetProgramiv(exec, _mesa_GetProgramiv);
      SET_GetQueryObjecti64v(exec, _mesa_GetQueryObjecti64v);
      SET_GetQueryObjectiv(exec, _mesa_GetQueryObjectiv);
      SET_GetQueryObjectui64v(exec, _mesa_GetQueryObjectui64v);
      SET_GetQueryObjectuiv(exec, _mesa_GetQueryObjectuiv);
      SET_GetQueryiv(exec, _mesa_GetQueryiv);
      SET_GetShaderInfoLog(exec, _mesa_GetShaderInfoLog);
      SET_GetShaderPrecisionFormat(exec, _mesa_GetShaderPrecisionFormat);
      SET_GetShaderSource(exec, _mesa_GetShaderSource);
      SET_GetShaderiv(exec, _mesa_GetShaderiv);
      SET_GetUniformfv(exec, _mesa_GetUniformfv);
      SET_GetUniformiv(exec, _mesa_GetUniformiv);
      SET_GetVertexAttribPointerv(exec, _mesa_GetVertexAttribPointerv);
      SET_GetVertexAttribfv(exec, _mesa_GetVertexAttribfv);
      SET_GetVertexAttribiv(exec, _mesa_GetVertexAttribiv);
      SET_GetnUniformfvARB(exec, _mesa_GetnUniformfvARB);
      SET_GetnUniformivARB(exec, _mesa_GetnUniformivARB);
      SET_GetnUniformuivARB(exec, _mesa_GetnUniformuivARB);
      SET_InternalBufferSubDataCopyMESA(exec, _mesa_InternalBufferSubDataCopyMESA);
      SET_IsProgram(exec, _mesa_IsProgram);
      SET_IsProgramPipeline(exec, _mesa_IsProgramPipeline);
      SET_IsQuery(exec, _mesa_IsQuery);
      SET_IsShader(exec, _mesa_IsShader);
      SET_IsVertexArray(exec, _mesa_IsVertexArray);
      SET_MaxShaderCompilerThreadsKHR(exec, _mesa_MaxShaderCompilerThreadsKHR);
      SET_MultiDrawElementsBaseVertex(exec, _mesa_MultiDrawElementsBaseVertex);
      SET_ProgramBinary(exec, _mesa_ProgramBinary);
      SET_ProgramUniform1f(exec, _mesa_ProgramUniform1f);
      SET_ProgramUniform1fv(exec, _mesa_ProgramUniform1fv);
      SET_ProgramUniform1i(exec, _mesa_ProgramUniform1i);
      SET_ProgramUniform1iv(exec, _mesa_ProgramUniform1iv);
      SET_ProgramUniform2f(exec, _mesa_ProgramUniform2f);
      SET_ProgramUniform2fv(exec, _mesa_ProgramUniform2fv);
      SET_ProgramUniform2i(exec, _mesa_ProgramUniform2i);
      SET_ProgramUniform2iv(exec, _mesa_ProgramUniform2iv);
      SET_ProgramUniform3f(exec, _mesa_ProgramUniform3f);
      SET_ProgramUniform3fv(exec, _mesa_ProgramUniform3fv);
      SET_ProgramUniform3i(exec, _mesa_ProgramUniform3i);
      SET_ProgramUniform3iv(exec, _mesa_ProgramUniform3iv);
      SET_ProgramUniform4f(exec, _mesa_ProgramUniform4f);
      SET_ProgramUniform4fv(exec, _mesa_ProgramUniform4fv);
      SET_ProgramUniform4i(exec, _mesa_ProgramUniform4i);
      SET_ProgramUniform4iv(exec, _mesa_ProgramUniform4iv);
      SET_ProgramUniformMatrix2fv(exec, _mesa_ProgramUniformMatrix2fv);
      SET_ProgramUniformMatrix2x3fv(exec, _mesa_ProgramUniformMatrix2x3fv);
      SET_ProgramUniformMatrix2x4fv(exec, _mesa_ProgramUniformMatrix2x4fv);
      SET_ProgramUniformMatrix3fv(exec, _mesa_ProgramUniformMatrix3fv);
      SET_ProgramUniformMatrix3x2fv(exec, _mesa_ProgramUniformMatrix3x2fv);
      SET_ProgramUniformMatrix3x4fv(exec, _mesa_ProgramUniformMatrix3x4fv);
      SET_ProgramUniformMatrix4fv(exec, _mesa_ProgramUniformMatrix4fv);
      SET_ProgramUniformMatrix4x2fv(exec, _mesa_ProgramUniformMatrix4x2fv);
      SET_ProgramUniformMatrix4x3fv(exec, _mesa_ProgramUniformMatrix4x3fv);
      SET_QueryCounter(exec, _mesa_QueryCounter);
      SET_ReleaseShaderCompiler(exec, _mesa_ReleaseShaderCompiler);
      SET_RenderbufferStorageMultisample(exec, _mesa_RenderbufferStorageMultisample);
      SET_SelectPerfMonitorCountersAMD(exec, _mesa_SelectPerfMonitorCountersAMD);
      SET_ShaderBinary(exec, _mesa_ShaderBinary);
      SET_Uniform1f(exec, _mesa_Uniform1f);
      SET_Uniform1fv(exec, _mesa_Uniform1fv);
      SET_Uniform1i(exec, _mesa_Uniform1i);
      SET_Uniform1iv(exec, _mesa_Uniform1iv);
      SET_Uniform2f(exec, _mesa_Uniform2f);
      SET_Uniform2fv(exec, _mesa_Uniform2fv);
      SET_Uniform2i(exec, _mesa_Uniform2i);
      SET_Uniform2iv(exec, _mesa_Uniform2iv);
      SET_Uniform3f(exec, _mesa_Uniform3f);
      SET_Uniform3fv(exec, _mesa_Uniform3fv);
      SET_Uniform3i(exec, _mesa_Uniform3i);
      SET_Uniform3iv(exec, _mesa_Uniform3iv);
      SET_Uniform4f(exec, _mesa_Uniform4f);
      SET_Uniform4fv(exec, _mesa_Uniform4fv);
      SET_Uniform4i(exec, _mesa_Uniform4i);
      SET_Uniform4iv(exec, _mesa_Uniform4iv);
      SET_UniformMatrix2fv(exec, _mesa_UniformMatrix2fv);
      SET_UniformMatrix3fv(exec, _mesa_UniformMatrix3fv);
      SET_UniformMatrix4fv(exec, _mesa_UniformMatrix4fv);
      SET_ValidateProgram(exec, _mesa_ValidateProgram);
      SET_ValidateProgramPipeline(exec, _mesa_ValidateProgramPipeline);
   }
   if (_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx) || (ctx->API == API_OPENGLES2 && ctx->Version >= 30))) {
      SET_BeginTransformFeedback(exec, _mesa_BeginTransformFeedback_no_error);
      SET_BindBufferRange(exec, _mesa_BindBufferRange_no_error);
      SET_BindFragDataLocation(exec, _mesa_BindFragDataLocation_no_error);
      SET_BindFragDataLocationIndexed(exec, _mesa_BindFragDataLocationIndexed_no_error);
      SET_BindSampler(exec, _mesa_BindSampler_no_error);
      SET_BindTransformFeedback(exec, _mesa_BindTransformFeedback_no_error);
      SET_BlendEquationSeparateiARB(exec, _mesa_BlendEquationSeparateiARB_no_error);
      SET_BlendEquationiARB(exec, _mesa_BlendEquationiARB_no_error);
      SET_BlendFuncSeparateiARB(exec, _mesa_BlendFuncSeparateiARB_no_error);
      SET_BlendFunciARB(exec, _mesa_BlendFunciARB_no_error);
      SET_BlitFramebuffer(exec, _mesa_BlitFramebuffer_no_error);
      SET_ClearBufferfi(exec, _mesa_ClearBufferfi_no_error);
      SET_ClearBufferfv(exec, _mesa_ClearBufferfv_no_error);
      SET_ClearBufferiv(exec, _mesa_ClearBufferiv_no_error);
      SET_ClearBufferuiv(exec, _mesa_ClearBufferuiv_no_error);
      SET_ClientWaitSync(exec, _mesa_ClientWaitSync_no_error);
      SET_CopyBufferSubData(exec, _mesa_CopyBufferSubData_no_error);
      SET_CopyImageSubData(exec, _mesa_CopyImageSubData_no_error);
      SET_DeleteSamplers(exec, _mesa_DeleteSamplers_no_error);
      SET_DeleteSync(exec, _mesa_DeleteSync_no_error);
      SET_EndTransformFeedback(exec, _mesa_EndTransformFeedback_no_error);
      SET_FenceSync(exec, _mesa_FenceSync_no_error);
      SET_FramebufferTextureLayer(exec, _mesa_FramebufferTextureLayer_no_error);
      SET_GenSamplers(exec, _mesa_GenSamplers_no_error);
      SET_InvalidateFramebuffer(exec, _mesa_InvalidateFramebuffer_no_error);
      SET_InvalidateSubFramebuffer(exec, _mesa_InvalidateSubFramebuffer_no_error);
      SET_MinSampleShading(exec, _mesa_MinSampleShading_no_error);
      SET_PauseTransformFeedback(exec, _mesa_PauseTransformFeedback_no_error);
      SET_ResumeTransformFeedback(exec, _mesa_ResumeTransformFeedback_no_error);
      SET_TexStorage2D(exec, _mesa_TexStorage2D_no_error);
      SET_TexStorage3D(exec, _mesa_TexStorage3D_no_error);
      SET_TransformFeedbackVaryings(exec, _mesa_TransformFeedbackVaryings_no_error);
      SET_UniformBlockBinding(exec, _mesa_UniformBlockBinding_no_error);
      SET_VertexAttribDivisor(exec, _mesa_VertexAttribDivisor_no_error);
      SET_VertexAttribIPointer(exec, _mesa_VertexAttribIPointer_no_error);
      SET_WaitSync(exec, _mesa_WaitSync_no_error);
   }
   if (_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx) || (ctx->API == API_OPENGLES2 && ctx->Version >= 31))) {
      SET_BindImageTexture(exec, _mesa_BindImageTexture_no_error);
      SET_BindVertexBuffer(exec, _mesa_BindVertexBuffer_no_error);
      SET_BufferStorage(exec, _mesa_BufferStorage_no_error);
      SET_DispatchCompute(exec, _mesa_DispatchCompute_no_error);
      SET_DispatchComputeIndirect(exec, _mesa_DispatchComputeIndirect_no_error);
      SET_FramebufferSampleLocationsfvARB(exec, _mesa_FramebufferSampleLocationsfvARB_no_error);
      SET_MemoryBarrierByRegion(exec, _mesa_MemoryBarrierByRegion_no_error);
      SET_NamedFramebufferSampleLocationsfvARB(exec, _mesa_NamedFramebufferSampleLocationsfvARB_no_error);
      SET_PatchParameteri(exec, _mesa_PatchParameteri_no_error);
      SET_SampleMaski(exec, _mesa_SampleMaski_no_error);
      SET_TextureView(exec, _mesa_TextureView_no_error);
      SET_VertexAttribBinding(exec, _mesa_VertexAttribBinding_no_error);
      SET_VertexBindingDivisor(exec, _mesa_VertexBindingDivisor_no_error);
      SET_ViewportSwizzleNV(exec, _mesa_ViewportSwizzleNV_no_error);
   }
   if (_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx) || (ctx->API == API_OPENGLES2 && ctx->Version >= 32))) {
      SET_BufferStorageMemEXT(exec, _mesa_BufferStorageMemEXT_no_error);
      SET_NamedBufferStorageMemEXT(exec, _mesa_NamedBufferStorageMemEXT_no_error);
   }
   if (_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx) || ctx->API == API_OPENGLES || ctx->API == API_OPENGLES2)) {
      SET_ActiveTexture(exec, _mesa_ActiveTexture_no_error);
      SET_BindBuffer(exec, _mesa_BindBuffer_no_error);
      SET_BindTexture(exec, _mesa_BindTexture_no_error);
      SET_BlendEquationSeparate(exec, _mesa_BlendEquationSeparate_no_error);
      SET_BlendFunc(exec, _mesa_BlendFunc_no_error);
      SET_BlendFuncSeparate(exec, _mesa_BlendFuncSeparate_no_error);
      SET_BufferData(exec, _mesa_BufferData_no_error);
      SET_BufferSubData(exec, _mesa_BufferSubData_no_error);
      SET_CheckFramebufferStatus(exec, _mesa_CheckFramebufferStatus_no_error);
      SET_Clear(exec, _mesa_Clear_no_error);
      SET_CompressedTexImage2D(exec, _mesa_CompressedTexImage2D_no_error);
      SET_CompressedTexSubImage2D(exec, _mesa_CompressedTexSubImage2D_no_error);
      SET_ConservativeRasterParameterfNV(exec, _mesa_ConservativeRasterParameterfNV_no_error);
      SET_ConservativeRasterParameteriNV(exec, _mesa_ConservativeRasterParameteriNV_no_error);
      SET_CopyTexImage2D(exec, _mesa_CopyTexImage2D_no_error);
      SET_CopyTexSubImage2D(exec, _mesa_CopyTexSubImage2D_no_error);
      SET_CullFace(exec, _mesa_CullFace_no_error);
      SET_DeleteBuffers(exec, _mesa_DeleteBuffers_no_error);
      SET_DeleteTextures(exec, _mesa_DeleteTextures_no_error);
      SET_DepthFunc(exec, _mesa_DepthFunc_no_error);
      SET_FlushMappedBufferRange(exec, _mesa_FlushMappedBufferRange_no_error);
      SET_FramebufferRenderbuffer(exec, _mesa_FramebufferRenderbuffer_no_error);
      SET_FramebufferTexture2D(exec, _mesa_FramebufferTexture2D_no_error);
      SET_FrontFace(exec, _mesa_FrontFace_no_error);
      SET_GenBuffers(exec, _mesa_GenBuffers_no_error);
      SET_GenRenderbuffers(exec, _mesa_GenRenderbuffers_no_error);
      SET_GenTextures(exec, _mesa_GenTextures_no_error);
      SET_GenerateMipmap(exec, _mesa_GenerateMipmap_no_error);
      SET_LineWidth(exec, _mesa_LineWidth_no_error);
      SET_MapBuffer(exec, _mesa_MapBuffer_no_error);
      SET_MapBufferRange(exec, _mesa_MapBufferRange_no_error);
      SET_PixelStorei(exec, _mesa_PixelStorei_no_error);
      SET_ReadPixels(exec, _mesa_ReadPixels_no_error);
      SET_Scissor(exec, _mesa_Scissor_no_error);
      SET_StencilFunc(exec, _mesa_StencilFunc_no_error);
      SET_StencilOp(exec, _mesa_StencilOp_no_error);
      SET_SubpixelPrecisionBiasNV(exec, _mesa_SubpixelPrecisionBiasNV_no_error);
      SET_TexImage2D(exec, _mesa_TexImage2D_no_error);
      SET_TexSubImage2D(exec, _mesa_TexSubImage2D_no_error);
      SET_UnmapBuffer(exec, _mesa_UnmapBuffer_no_error);
      SET_Viewport(exec, _mesa_Viewport_no_error);
   }
   if (_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx) || ctx->API == API_OPENGLES)) {
      SET_LogicOp(exec, _mesa_LogicOp_no_error);
      SET_PointSize(exec, _mesa_PointSize_no_error);
   }
   if (_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx) || ctx->API == API_OPENGLES2)) {
      SET_ActiveShaderProgram(exec, _mesa_ActiveShaderProgram_no_error);
      SET_AttachShader(exec, _mesa_AttachShader_no_error);
      SET_BeginConditionalRender(exec, _mesa_BeginConditionalRender_no_error);
      SET_BindAttribLocation(exec, _mesa_BindAttribLocation_no_error);
      SET_BindProgramPipeline(exec, _mesa_BindProgramPipeline_no_error);
      SET_BindVertexArray(exec, _mesa_BindVertexArray_no_error);
      SET_ClipControl(exec, _mesa_ClipControl_no_error);
      SET_CompressedTexImage3D(exec, _mesa_CompressedTexImage3D_no_error);
      SET_CompressedTexSubImage3D(exec, _mesa_CompressedTexSubImage3D_no_error);
      SET_CopyTexSubImage3D(exec, _mesa_CopyTexSubImage3D_no_error);
      SET_CreateShader(exec, _mesa_CreateShader_no_error);
      SET_DeleteVertexArrays(exec, _mesa_DeleteVertexArrays_no_error);
      SET_DetachShader(exec, _mesa_DetachShader_no_error);
      SET_DisableVertexAttribArray(exec, _mesa_DisableVertexAttribArray_no_error);
      SET_DrawBuffers(exec, _mesa_DrawBuffers_no_error);
      SET_EnableVertexAttribArray(exec, _mesa_EnableVertexAttribArray_no_error);
      SET_EndConditionalRender(exec, _mesa_EndConditionalRender_no_error);
      SET_FramebufferTexture3D(exec, _mesa_FramebufferTexture3D_no_error);
      SET_GenProgramPipelines(exec, _mesa_GenProgramPipelines_no_error);
      SET_GenVertexArrays(exec, _mesa_GenVertexArrays_no_error);
      SET_GetUniformLocation(exec, _mesa_GetUniformLocation_no_error);
      SET_LinkProgram(exec, _mesa_LinkProgram_no_error);
      SET_ProgramParameteri(exec, _mesa_ProgramParameteri_no_error);
      SET_ReadBuffer(exec, _mesa_ReadBuffer_no_error);
      SET_ReadnPixelsARB(exec, _mesa_ReadnPixelsARB_no_error);
      SET_ShaderSource(exec, _mesa_ShaderSource_no_error);
      SET_StencilFuncSeparate(exec, _mesa_StencilFuncSeparate_no_error);
      SET_StencilMaskSeparate(exec, _mesa_StencilMaskSeparate_no_error);
      SET_StencilOpSeparate(exec, _mesa_StencilOpSeparate_no_error);
      SET_TexImage3D(exec, _mesa_TexImage3D_no_error);
      SET_TexSubImage3D(exec, _mesa_TexSubImage3D_no_error);
      SET_UseProgram(exec, _mesa_UseProgram_no_error);
      SET_UseProgramStages(exec, _mesa_UseProgramStages_no_error);
      SET_VertexAttribPointer(exec, _mesa_VertexAttribPointer_no_error);
   }
   if (_mesa_is_no_error_enabled(ctx) && (_mesa_is_desktop_gl(ctx))) {
      SET_AlphaToCoverageDitherControlNV(exec, _mesa_AlphaToCoverageDitherControlNV_no_error);
      SET_AttachObjectARB(exec, _mesa_AttachObjectARB_no_error);
      SET_BindBufferOffsetEXT(exec, _mesa_BindBufferOffsetEXT_no_error);
      SET_BindImageTextures(exec, _mesa_BindImageTextures_no_error);
      SET_BindSamplers(exec, _mesa_BindSamplers_no_error);
      SET_BindTextures(exec, _mesa_BindTextures_no_error);
      SET_BindVertexBuffers(exec, _mesa_BindVertexBuffers_no_error);
      SET_ClearBufferData(exec, _mesa_ClearBufferData_no_error);
      SET_ClearBufferSubData(exec, _mesa_ClearBufferSubData_no_error);
      SET_CompressedTexImage1D(exec, _mesa_CompressedTexImage1D_no_error);
      SET_CompressedTexSubImage1D(exec, _mesa_CompressedTexSubImage1D_no_error);
      SET_CopyImageSubDataNV(exec, _mesa_CopyImageSubDataNV_no_error);
      SET_CopyTexImage1D(exec, _mesa_CopyTexImage1D_no_error);
      SET_CopyTexSubImage1D(exec, _mesa_CopyTexSubImage1D_no_error);
      SET_CreateShaderObjectARB(exec, _mesa_CreateShaderObjectARB_no_error);
      SET_DetachObjectARB(exec, _mesa_DetachObjectARB_no_error);
      SET_DispatchComputeGroupSizeARB(exec, _mesa_DispatchComputeGroupSizeARB_no_error);
      SET_DrawBuffer(exec, _mesa_DrawBuffer_no_error);
      SET_FramebufferTexture1D(exec, _mesa_FramebufferTexture1D_no_error);
      SET_GetImageHandleARB(exec, _mesa_GetImageHandleARB_no_error);
      SET_GetTextureHandleARB(exec, _mesa_GetTextureHandleARB_no_error);
      SET_GetTextureSamplerHandleARB(exec, _mesa_GetTextureSamplerHandleARB_no_error);
      SET_InvalidateBufferData(exec, _mesa_InvalidateBufferData_no_error);
      SET_InvalidateBufferSubData(exec, _mesa_InvalidateBufferSubData_no_error);
      SET_InvalidateTexImage(exec, _mesa_InvalidateTexImage_no_error);
      SET_InvalidateTexSubImage(exec, _mesa_InvalidateTexSubImage_no_error);
      SET_IsImageHandleResidentARB(exec, _mesa_IsImageHandleResidentARB_no_error);
      SET_IsTextureHandleResidentARB(exec, _mesa_IsTextureHandleResidentARB_no_error);
      SET_MakeImageHandleNonResidentARB(exec, _mesa_MakeImageHandleNonResidentARB_no_error);
      SET_MakeImageHandleResidentARB(exec, _mesa_MakeImageHandleResidentARB_no_error);
      SET_MakeTextureHandleNonResidentARB(exec, _mesa_MakeTextureHandleNonResidentARB_no_error);
      SET_MakeTextureHandleResidentARB(exec, _mesa_MakeTextureHandleResidentARB_no_error);
      SET_PixelStoref(exec, _mesa_PixelStoref_no_error);
      SET_PolygonMode(exec, _mesa_PolygonMode_no_error);
      SET_PrimitiveRestartIndex(exec, _mesa_PrimitiveRestartIndex_no_error);
      SET_ShaderStorageBlockBinding(exec, _mesa_ShaderStorageBlockBinding_no_error);
      SET_TexImage1D(exec, _mesa_TexImage1D_no_error);
      SET_TexStorage1D(exec, _mesa_TexStorage1D_no_error);
      SET_TexSubImage1D(exec, _mesa_TexSubImage1D_no_error);
      SET_UnmapNamedBufferEXT(exec, _mesa_UnmapNamedBufferEXT_no_error);
   }
   if (_mesa_is_no_error_enabled(ctx) && (ctx->API == API_OPENGLES)) {
      SET_PointSizePointerOES(exec, _mesa_PointSizePointerOES_no_error);
   }
   if (_mesa_is_no_error_enabled(ctx) && (ctx->API == API_OPENGL_COMPAT || ctx->API == API_OPENGLES)) {
      SET_ColorPointer(exec, _mesa_ColorPointer_no_error);
      SET_NormalPointer(exec, _mesa_NormalPointer_no_error);
      SET_TexCoordPointer(exec, _mesa_TexCoordPointer_no_error);
      SET_VertexPointer(exec, _mesa_VertexPointer_no_error);
   }
   if (_mesa_is_no_error_enabled(ctx) && (ctx->API == API_OPENGL_COMPAT || ctx->API == API_OPENGL_CORE || (ctx->API == API_OPENGLES2 && ctx->Version >= 31))) {
      SET_FramebufferTexture(exec, _mesa_FramebufferTexture_no_error);
      SET_ScissorArrayv(exec, _mesa_ScissorArrayv_no_error);
      SET_ScissorIndexed(exec, _mesa_ScissorIndexed_no_error);
      SET_ScissorIndexedv(exec, _mesa_ScissorIndexedv_no_error);
      SET_ViewportArrayv(exec, _mesa_ViewportArrayv_no_error);
      SET_ViewportIndexedf(exec, _mesa_ViewportIndexedf_no_error);
      SET_ViewportIndexedfv(exec, _mesa_ViewportIndexedfv_no_error);
   }
   if (_mesa_is_no_error_enabled(ctx) && (ctx->API == API_OPENGL_COMPAT || ctx->API == API_OPENGL_CORE)) {
      SET_BindTextureUnit(exec, _mesa_BindTextureUnit_no_error);
      SET_BlitNamedFramebuffer(exec, _mesa_BlitNamedFramebuffer_no_error);
      SET_ClearNamedBufferData(exec, _mesa_ClearNamedBufferData_no_error);
      SET_ClearNamedBufferSubData(exec, _mesa_ClearNamedBufferSubData_no_error);
      SET_CompressedTextureSubImage1D(exec, _mesa_CompressedTextureSubImage1D_no_error);
      SET_CompressedTextureSubImage2D(exec, _mesa_CompressedTextureSubImage2D_no_error);
      SET_CompressedTextureSubImage3D(exec, _mesa_CompressedTextureSubImage3D_no_error);
      SET_CopyNamedBufferSubData(exec, _mesa_CopyNamedBufferSubData_no_error);
      SET_CopyTextureSubImage1D(exec, _mesa_CopyTextureSubImage1D_no_error);
      SET_CopyTextureSubImage2D(exec, _mesa_CopyTextureSubImage2D_no_error);
      SET_CopyTextureSubImage3D(exec, _mesa_CopyTextureSubImage3D_no_error);
      SET_CreateBuffers(exec, _mesa_CreateBuffers_no_error);
      SET_CreateProgramPipelines(exec, _mesa_CreateProgramPipelines_no_error);
      SET_CreateRenderbuffers(exec, _mesa_CreateRenderbuffers_no_error);
      SET_CreateSamplers(exec, _mesa_CreateSamplers_no_error);
      SET_CreateTextures(exec, _mesa_CreateTextures_no_error);
      SET_CreateVertexArrays(exec, _mesa_CreateVertexArrays_no_error);
      SET_DepthRangeArrayv(exec, _mesa_DepthRangeArrayv_no_error);
      SET_DepthRangeIndexed(exec, _mesa_DepthRangeIndexed_no_error);
      SET_DisableVertexArrayAttrib(exec, _mesa_DisableVertexArrayAttrib_no_error);
      SET_EnableVertexArrayAttrib(exec, _mesa_EnableVertexArrayAttrib_no_error);
      SET_FlushMappedNamedBufferRange(exec, _mesa_FlushMappedNamedBufferRange_no_error);
      SET_GenerateTextureMipmap(exec, _mesa_GenerateTextureMipmap_no_error);
      SET_MapNamedBuffer(exec, _mesa_MapNamedBuffer_no_error);
      SET_MapNamedBufferRange(exec, _mesa_MapNamedBufferRange_no_error);
      SET_NamedBufferData(exec, _mesa_NamedBufferData_no_error);
      SET_NamedBufferStorage(exec, _mesa_NamedBufferStorage_no_error);
      SET_NamedBufferSubData(exec, _mesa_NamedBufferSubData_no_error);
      SET_NamedFramebufferDrawBuffer(exec, _mesa_NamedFramebufferDrawBuffer_no_error);
      SET_NamedFramebufferDrawBuffers(exec, _mesa_NamedFramebufferDrawBuffers_no_error);
      SET_NamedFramebufferReadBuffer(exec, _mesa_NamedFramebufferReadBuffer_no_error);
      SET_NamedFramebufferRenderbuffer(exec, _mesa_NamedFramebufferRenderbuffer_no_error);
      SET_NamedFramebufferTexture(exec, _mesa_NamedFramebufferTexture_no_error);
      SET_NamedFramebufferTextureLayer(exec, _mesa_NamedFramebufferTextureLayer_no_error);
      SET_TextureStorage1D(exec, _mesa_TextureStorage1D_no_error);
      SET_TextureStorage2D(exec, _mesa_TextureStorage2D_no_error);
      SET_TextureStorage3D(exec, _mesa_TextureStorage3D_no_error);
      SET_TextureSubImage1D(exec, _mesa_TextureSubImage1D_no_error);
      SET_TextureSubImage2D(exec, _mesa_TextureSubImage2D_no_error);
      SET_TextureSubImage3D(exec, _mesa_TextureSubImage3D_no_error);
      SET_VertexArrayAttribBinding(exec, _mesa_VertexArrayAttribBinding_no_error);
      SET_VertexArrayBindingDivisor(exec, _mesa_VertexArrayBindingDivisor_no_error);
      SET_VertexArrayElementBuffer(exec, _mesa_VertexArrayElementBuffer_no_error);
      SET_VertexArrayVertexBuffer(exec, _mesa_VertexArrayVertexBuffer_no_error);
      SET_VertexArrayVertexBuffers(exec, _mesa_VertexArrayVertexBuffers_no_error);
      SET_VertexAttribLPointer(exec, _mesa_VertexAttribLPointer_no_error);
   }
   if (_mesa_is_no_error_enabled(ctx) && (ctx->API == API_OPENGL_COMPAT)) {
      SET_EdgeFlagPointer(exec, _mesa_EdgeFlagPointer_no_error);
      SET_FogCoordPointer(exec, _mesa_FogCoordPointer_no_error);
      SET_IndexPointer(exec, _mesa_IndexPointer_no_error);
      SET_SecondaryColorPointer(exec, _mesa_SecondaryColorPointer_no_error);
   }
   if (ctx->API == API_OPENGLES) {
      SET_AlphaFuncx(exec, _mesa_AlphaFuncx);
      SET_ClearColorx(exec, _mesa_ClearColorx);
      SET_ClearDepthx(exec, _mesa_ClearDepthx);
      SET_ClipPlanef(exec, _mesa_ClipPlanef);
      SET_ClipPlanex(exec, _mesa_ClipPlanex);
      SET_Color4x(exec, _mesa_Color4x);
      SET_DepthRangex(exec, _mesa_DepthRangex);
      SET_DrawTexfOES(exec, _mesa_DrawTexfOES);
      SET_DrawTexfvOES(exec, _mesa_DrawTexfvOES);
      SET_DrawTexiOES(exec, _mesa_DrawTexiOES);
      SET_DrawTexivOES(exec, _mesa_DrawTexivOES);
      SET_DrawTexsOES(exec, _mesa_DrawTexsOES);
      SET_DrawTexsvOES(exec, _mesa_DrawTexsvOES);
      SET_DrawTexxOES(exec, _mesa_DrawTexxOES);
      SET_DrawTexxvOES(exec, _mesa_DrawTexxvOES);
      SET_Fogx(exec, _mesa_Fogx);
      SET_Fogxv(exec, _mesa_Fogxv);
      SET_Frustumf(exec, _mesa_Frustumf);
      SET_Frustumx(exec, _mesa_Frustumx);
      SET_GetClipPlanef(exec, _mesa_GetClipPlanef);
      SET_GetClipPlanex(exec, _mesa_GetClipPlanex);
      SET_GetFixedv(exec, _mesa_GetFixedv);
      SET_GetLightxv(exec, _mesa_GetLightxv);
      SET_GetMaterialxv(exec, _mesa_GetMaterialxv);
      SET_GetTexEnvxv(exec, _mesa_GetTexEnvxv);
      SET_GetTexGenxvOES(exec, _mesa_GetTexGenxvOES);
      SET_GetTexParameterxv(exec, _mesa_GetTexParameterxv);
      SET_LightModelx(exec, _mesa_LightModelx);
      SET_LightModelxv(exec, _mesa_LightModelxv);
      SET_Lightx(exec, _mesa_Lightx);
      SET_Lightxv(exec, _mesa_Lightxv);
      SET_LineWidthx(exec, _mesa_LineWidthx);
      SET_LoadMatrixx(exec, _mesa_LoadMatrixx);
      SET_Materialx(exec, _mesa_Materialx);
      SET_Materialxv(exec, _mesa_Materialxv);
      SET_MultMatrixx(exec, _mesa_MultMatrixx);
      SET_MultiTexCoord4x(exec, _mesa_MultiTexCoord4x);
      SET_Normal3x(exec, _mesa_Normal3x);
      SET_Orthof(exec, _mesa_Orthof);
      SET_Orthox(exec, _mesa_Orthox);
      SET_PointParameterx(exec, _mesa_PointParameterx);
      SET_PointParameterxv(exec, _mesa_PointParameterxv);
      SET_PointSizex(exec, _mesa_PointSizex);
      SET_PolygonOffsetx(exec, _mesa_PolygonOffsetx);
      SET_QueryMatrixxOES(exec, _mesa_QueryMatrixxOES);
      SET_Rotatex(exec, _mesa_Rotatex);
      SET_SampleCoveragex(exec, _mesa_SampleCoveragex);
      SET_Scalex(exec, _mesa_Scalex);
      SET_TexEnvx(exec, _mesa_TexEnvx);
      SET_TexEnvxv(exec, _mesa_TexEnvxv);
      SET_TexGenxOES(exec, _mesa_TexGenxOES);
      SET_TexGenxvOES(exec, _mesa_TexGenxvOES);
      SET_TexParameterx(exec, _mesa_TexParameterx);
      SET_TexParameterxv(exec, _mesa_TexParameterxv);
      SET_Translatex(exec, _mesa_Translatex);
   }
   if (ctx->API == API_OPENGLES || ctx->API == API_OPENGLES2) {
      SET_DiscardFramebufferEXT(exec, _mesa_DiscardFramebufferEXT);
   }
   if (ctx->API == API_OPENGLES2) {
      SET_FramebufferTexture2DMultisampleEXT(exec, _mesa_FramebufferTexture2DMultisampleEXT);
   }
   if (ctx->API == API_OPENGL_COMPAT) {
      SET_Accum(exec, _mesa_Accum);
      SET_ActiveStencilFaceEXT(exec, _mesa_ActiveStencilFaceEXT);
      SET_AlphaFragmentOp1ATI(exec, _mesa_AlphaFragmentOp1ATI);
      SET_AlphaFragmentOp2ATI(exec, _mesa_AlphaFragmentOp2ATI);
      SET_AlphaFragmentOp3ATI(exec, _mesa_AlphaFragmentOp3ATI);
      SET_AreTexturesResident(exec, _mesa_AreTexturesResident);
      SET_BeginFragmentShaderATI(exec, _mesa_BeginFragmentShaderATI);
      SET_BindFragmentShaderATI(exec, _mesa_BindFragmentShaderATI);
      SET_BindProgramARB(exec, _mesa_BindProgramARB);
      SET_Bitmap(exec, _mesa_Bitmap);
      SET_ClearAccum(exec, _mesa_ClearAccum);
      SET_ClearIndex(exec, _mesa_ClearIndex);
      SET_ClipPlane(exec, _mesa_ClipPlane);
      SET_ColorFragmentOp1ATI(exec, _mesa_ColorFragmentOp1ATI);
      SET_ColorFragmentOp2ATI(exec, _mesa_ColorFragmentOp2ATI);
      SET_ColorFragmentOp3ATI(exec, _mesa_ColorFragmentOp3ATI);
      SET_ColorMaterial(exec, _mesa_ColorMaterial);
      SET_ColorPointerEXT(exec, _mesa_ColorPointerEXT);
      SET_CopyPixels(exec, _mesa_CopyPixels);
      SET_DeleteFragmentShaderATI(exec, _mesa_DeleteFragmentShaderATI);
      SET_DeleteLists(exec, _mesa_DeleteLists);
      SET_DeleteProgramsARB(exec, _mesa_DeleteProgramsARB);
      SET_DrawPixels(exec, _mesa_DrawPixels);
      SET_EdgeFlagPointerEXT(exec, _mesa_EdgeFlagPointerEXT);
      SET_EndFragmentShaderATI(exec, _mesa_EndFragmentShaderATI);
      SET_EndList(exec, _mesa_EndList);
      SET_EvalMesh1(exec, _mesa_EvalMesh1);
      SET_EvalMesh2(exec, _mesa_EvalMesh2);
      SET_FeedbackBuffer(exec, _mesa_FeedbackBuffer);
      SET_Fogi(exec, _mesa_Fogi);
      SET_Fogiv(exec, _mesa_Fogiv);
      SET_Frustum(exec, _mesa_Frustum);
      SET_GenFragmentShadersATI(exec, _mesa_GenFragmentShadersATI);
      SET_GenLists(exec, _mesa_GenLists);
      SET_GenProgramsARB(exec, _mesa_GenProgramsARB);
      SET_GetClipPlane(exec, _mesa_GetClipPlane);
      SET_GetLightiv(exec, _mesa_GetLightiv);
      SET_GetMapdv(exec, _mesa_GetMapdv);
      SET_GetMapfv(exec, _mesa_GetMapfv);
      SET_GetMapiv(exec, _mesa_GetMapiv);
      SET_GetMaterialiv(exec, _mesa_GetMaterialiv);
      SET_GetPixelMapfv(exec, _mesa_GetPixelMapfv);
      SET_GetPixelMapuiv(exec, _mesa_GetPixelMapuiv);
      SET_GetPixelMapusv(exec, _mesa_GetPixelMapusv);
      SET_GetPolygonStipple(exec, _mesa_GetPolygonStipple);
      SET_GetProgramEnvParameterdvARB(exec, _mesa_GetProgramEnvParameterdvARB);
      SET_GetProgramEnvParameterfvARB(exec, _mesa_GetProgramEnvParameterfvARB);
      SET_GetProgramLocalParameterdvARB(exec, _mesa_GetProgramLocalParameterdvARB);
      SET_GetProgramLocalParameterfvARB(exec, _mesa_GetProgramLocalParameterfvARB);
      SET_GetProgramStringARB(exec, _mesa_GetProgramStringARB);
      SET_GetProgramivARB(exec, _mesa_GetProgramivARB);
      SET_GetTexGendv(exec, _mesa_GetTexGendv);
      SET_GetnMapdvARB(exec, _mesa_GetnMapdvARB);
      SET_GetnMapfvARB(exec, _mesa_GetnMapfvARB);
      SET_GetnMapivARB(exec, _mesa_GetnMapivARB);
      SET_GetnPixelMapfvARB(exec, _mesa_GetnPixelMapfvARB);
      SET_GetnPixelMapuivARB(exec, _mesa_GetnPixelMapuivARB);
      SET_GetnPixelMapusvARB(exec, _mesa_GetnPixelMapusvARB);
      SET_IndexMask(exec, _mesa_IndexMask);
      SET_IndexPointerEXT(exec, _mesa_IndexPointerEXT);
      SET_InitNames(exec, _mesa_InitNames);
      SET_InterleavedArrays(exec, _mesa_InterleavedArrays);
      SET_IsList(exec, _mesa_IsList);
      SET_IsProgramARB(exec, _mesa_IsProgramARB);
      SET_LightModeli(exec, _mesa_LightModeli);
      SET_LightModeliv(exec, _mesa_LightModeliv);
      SET_Lighti(exec, _mesa_Lighti);
      SET_Lightiv(exec, _mesa_Lightiv);
      SET_LineStipple(exec, _mesa_LineStipple);
      SET_ListBase(exec, _mesa_ListBase);
      SET_LoadMatrixd(exec, _mesa_LoadMatrixd);
      SET_LoadName(exec, _mesa_LoadName);
      SET_LoadTransposeMatrixd(exec, _mesa_LoadTransposeMatrixd);
      SET_LoadTransposeMatrixf(exec, _mesa_LoadTransposeMatrixf);
      SET_LockArraysEXT(exec, _mesa_LockArraysEXT);
      SET_Map1d(exec, _mesa_Map1d);
      SET_Map1f(exec, _mesa_Map1f);
      SET_Map2d(exec, _mesa_Map2d);
      SET_Map2f(exec, _mesa_Map2f);
      SET_MapGrid1d(exec, _mesa_MapGrid1d);
      SET_MapGrid1f(exec, _mesa_MapGrid1f);
      SET_MapGrid2d(exec, _mesa_MapGrid2d);
      SET_MapGrid2f(exec, _mesa_MapGrid2f);
      SET_MultMatrixd(exec, _mesa_MultMatrixd);
      SET_MultTransposeMatrixd(exec, _mesa_MultTransposeMatrixd);
      SET_MultTransposeMatrixf(exec, _mesa_MultTransposeMatrixf);
      SET_NewList(exec, _mesa_NewList);
      SET_NormalPointerEXT(exec, _mesa_NormalPointerEXT);
      SET_Ortho(exec, _mesa_Ortho);
      SET_PassTexCoordATI(exec, _mesa_PassTexCoordATI);
      SET_PassThrough(exec, _mesa_PassThrough);
      SET_PixelMapfv(exec, _mesa_PixelMapfv);
      SET_PixelMapuiv(exec, _mesa_PixelMapuiv);
      SET_PixelMapusv(exec, _mesa_PixelMapusv);
      SET_PixelTransferf(exec, _mesa_PixelTransferf);
      SET_PixelTransferi(exec, _mesa_PixelTransferi);
      SET_PixelZoom(exec, _mesa_PixelZoom);
      SET_PolygonStipple(exec, _mesa_PolygonStipple);
      SET_PopAttrib(exec, _mesa_PopAttrib);
      SET_PopClientAttrib(exec, _mesa_PopClientAttrib);
      SET_PopName(exec, _mesa_PopName);
      SET_PrioritizeTextures(exec, _mesa_PrioritizeTextures);
      SET_ProgramEnvParameter4dARB(exec, _mesa_ProgramEnvParameter4dARB);
      SET_ProgramEnvParameter4dvARB(exec, _mesa_ProgramEnvParameter4dvARB);
      SET_ProgramEnvParameter4fARB(exec, _mesa_ProgramEnvParameter4fARB);
      SET_ProgramEnvParameter4fvARB(exec, _mesa_ProgramEnvParameter4fvARB);
      SET_ProgramEnvParameters4fvEXT(exec, _mesa_ProgramEnvParameters4fvEXT);
      SET_ProgramLocalParameter4dARB(exec, _mesa_ProgramLocalParameter4dARB);
      SET_ProgramLocalParameter4dvARB(exec, _mesa_ProgramLocalParameter4dvARB);
      SET_ProgramLocalParameter4fARB(exec, _mesa_ProgramLocalParameter4fARB);
      SET_ProgramLocalParameter4fvARB(exec, _mesa_ProgramLocalParameter4fvARB);
      SET_ProgramLocalParameters4fvEXT(exec, _mesa_ProgramLocalParameters4fvEXT);
      SET_ProgramStringARB(exec, _mesa_ProgramStringARB);
      SET_PushAttrib(exec, _mesa_PushAttrib);
      SET_PushClientAttrib(exec, _mesa_PushClientAttrib);
      SET_PushName(exec, _mesa_PushName);
      SET_RasterPos2d(exec, _mesa_RasterPos2d);
      SET_RasterPos2dv(exec, _mesa_RasterPos2dv);
      SET_RasterPos2f(exec, _mesa_RasterPos2f);
      SET_RasterPos2fv(exec, _mesa_RasterPos2fv);
      SET_RasterPos2i(exec, _mesa_RasterPos2i);
      SET_RasterPos2iv(exec, _mesa_RasterPos2iv);
      SET_RasterPos2s(exec, _mesa_RasterPos2s);
      SET_RasterPos2sv(exec, _mesa_RasterPos2sv);
      SET_RasterPos3d(exec, _mesa_RasterPos3d);
      SET_RasterPos3dv(exec, _mesa_RasterPos3dv);
      SET_RasterPos3f(exec, _mesa_RasterPos3f);
      SET_RasterPos3fv(exec, _mesa_RasterPos3fv);
      SET_RasterPos3i(exec, _mesa_RasterPos3i);
      SET_RasterPos3iv(exec, _mesa_RasterPos3iv);
      SET_RasterPos3s(exec, _mesa_RasterPos3s);
      SET_RasterPos3sv(exec, _mesa_RasterPos3sv);
      SET_RasterPos4d(exec, _mesa_RasterPos4d);
      SET_RasterPos4dv(exec, _mesa_RasterPos4dv);
      SET_RasterPos4f(exec, _mesa_RasterPos4f);
      SET_RasterPos4fv(exec, _mesa_RasterPos4fv);
      SET_RasterPos4i(exec, _mesa_RasterPos4i);
      SET_RasterPos4iv(exec, _mesa_RasterPos4iv);
      SET_RasterPos4s(exec, _mesa_RasterPos4s);
      SET_RasterPos4sv(exec, _mesa_RasterPos4sv);
      SET_Rectd(exec, _mesa_Rectd);
      SET_Rectdv(exec, _mesa_Rectdv);
      SET_Rectf(exec, _mesa_Rectf);
      SET_Rectfv(exec, _mesa_Rectfv);
      SET_Recti(exec, _mesa_Recti);
      SET_Rectiv(exec, _mesa_Rectiv);
      SET_Rects(exec, _mesa_Rects);
      SET_Rectsv(exec, _mesa_Rectsv);
      SET_RenderMode(exec, _mesa_RenderMode);
      SET_Rotated(exec, _mesa_Rotated);
      SET_SampleMapATI(exec, _mesa_SampleMapATI);
      SET_Scaled(exec, _mesa_Scaled);
      SET_SelectBuffer(exec, _mesa_SelectBuffer);
      SET_SetFragmentShaderConstantATI(exec, _mesa_SetFragmentShaderConstantATI);
      SET_StencilFuncSeparateATI(exec, _mesa_StencilFuncSeparateATI);
      SET_TexCoordPointerEXT(exec, _mesa_TexCoordPointerEXT);
      SET_TexGend(exec, _mesa_TexGend);
      SET_TexGendv(exec, _mesa_TexGendv);
      SET_Translated(exec, _mesa_Translated);
      SET_UnlockArraysEXT(exec, _mesa_UnlockArraysEXT);
      SET_VertexPointerEXT(exec, _mesa_VertexPointerEXT);
      SET_WindowPos2d(exec, _mesa_WindowPos2d);
      SET_WindowPos2dv(exec, _mesa_WindowPos2dv);
      SET_WindowPos2f(exec, _mesa_WindowPos2f);
      SET_WindowPos2fv(exec, _mesa_WindowPos2fv);
      SET_WindowPos2i(exec, _mesa_WindowPos2i);
      SET_WindowPos2iv(exec, _mesa_WindowPos2iv);
      SET_WindowPos2s(exec, _mesa_WindowPos2s);
      SET_WindowPos2sv(exec, _mesa_WindowPos2sv);
      SET_WindowPos3d(exec, _mesa_WindowPos3d);
      SET_WindowPos3dv(exec, _mesa_WindowPos3dv);
      SET_WindowPos3f(exec, _mesa_WindowPos3f);
      SET_WindowPos3fv(exec, _mesa_WindowPos3fv);
      SET_WindowPos3i(exec, _mesa_WindowPos3i);
      SET_WindowPos3iv(exec, _mesa_WindowPos3iv);
      SET_WindowPos3s(exec, _mesa_WindowPos3s);
      SET_WindowPos3sv(exec, _mesa_WindowPos3sv);
      SET_WindowPos4dMESA(exec, _mesa_WindowPos4dMESA);
      SET_WindowPos4dvMESA(exec, _mesa_WindowPos4dvMESA);
      SET_WindowPos4fMESA(exec, _mesa_WindowPos4fMESA);
      SET_WindowPos4fvMESA(exec, _mesa_WindowPos4fvMESA);
      SET_WindowPos4iMESA(exec, _mesa_WindowPos4iMESA);
      SET_WindowPos4ivMESA(exec, _mesa_WindowPos4ivMESA);
      SET_WindowPos4sMESA(exec, _mesa_WindowPos4sMESA);
      SET_WindowPos4svMESA(exec, _mesa_WindowPos4svMESA);
   }
   if (ctx->API == API_OPENGL_COMPAT || ctx->API == API_OPENGLES) {
      SET_AlphaFunc(exec, _mesa_AlphaFunc);
      SET_ClientActiveTexture(exec, _mesa_ClientActiveTexture);
      SET_DisableClientState(exec, _mesa_DisableClientState);
      SET_EnableClientState(exec, _mesa_EnableClientState);
      SET_Fogf(exec, _mesa_Fogf);
      SET_Fogfv(exec, _mesa_Fogfv);
      SET_GetLightfv(exec, _mesa_GetLightfv);
      SET_GetMaterialfv(exec, _mesa_GetMaterialfv);
      SET_GetTexEnvfv(exec, _mesa_GetTexEnvfv);
      SET_GetTexEnviv(exec, _mesa_GetTexEnviv);
      SET_GetTexGenfv(exec, _mesa_GetTexGenfv);
      SET_GetTexGeniv(exec, _mesa_GetTexGeniv);
      SET_LightModelf(exec, _mesa_LightModelf);
      SET_LightModelfv(exec, _mesa_LightModelfv);
      SET_Lightf(exec, _mesa_Lightf);
      SET_Lightfv(exec, _mesa_Lightfv);
      SET_LoadIdentity(exec, _mesa_LoadIdentity);
      SET_LoadMatrixf(exec, _mesa_LoadMatrixf);
      SET_MatrixMode(exec, _mesa_MatrixMode);
      SET_MultMatrixf(exec, _mesa_MultMatrixf);
      SET_PopMatrix(exec, _mesa_PopMatrix);
      SET_PushMatrix(exec, _mesa_PushMatrix);
      SET_Rotatef(exec, _mesa_Rotatef);
      SET_Scalef(exec, _mesa_Scalef);
      SET_ShadeModel(exec, _mesa_ShadeModel);
      SET_TexEnvf(exec, _mesa_TexEnvf);
      SET_TexEnvfv(exec, _mesa_TexEnvfv);
      SET_TexEnvi(exec, _mesa_TexEnvi);
      SET_TexEnviv(exec, _mesa_TexEnviv);
      SET_TexGenf(exec, _mesa_TexGenf);
      SET_TexGenfv(exec, _mesa_TexGenfv);
      SET_TexGeni(exec, _mesa_TexGeni);
      SET_TexGeniv(exec, _mesa_TexGeniv);
      SET_Translatef(exec, _mesa_Translatef);
   }
   if (ctx->API == API_OPENGL_COMPAT || ctx->API == API_OPENGL_CORE) {
      SET_CheckNamedFramebufferStatus(exec, _mesa_CheckNamedFramebufferStatus);
      SET_ClearNamedFramebufferfi(exec, _mesa_ClearNamedFramebufferfi);
      SET_ClearNamedFramebufferfv(exec, _mesa_ClearNamedFramebufferfv);
      SET_ClearNamedFramebufferiv(exec, _mesa_ClearNamedFramebufferiv);
      SET_ClearNamedFramebufferuiv(exec, _mesa_ClearNamedFramebufferuiv);
      SET_CreateFramebuffers(exec, _mesa_CreateFramebuffers);
      SET_CreateQueries(exec, _mesa_CreateQueries);
      SET_CreateTransformFeedbacks(exec, _mesa_CreateTransformFeedbacks);
      SET_GetActiveSubroutineName(exec, _mesa_GetActiveSubroutineName);
      SET_GetActiveSubroutineUniformName(exec, _mesa_GetActiveSubroutineUniformName);
      SET_GetActiveSubroutineUniformiv(exec, _mesa_GetActiveSubroutineUniformiv);
      SET_GetCompressedTextureImage(exec, _mesa_GetCompressedTextureImage);
      SET_GetNamedBufferParameteri64v(exec, _mesa_GetNamedBufferParameteri64v);
      SET_GetNamedBufferParameteriv(exec, _mesa_GetNamedBufferParameteriv);
      SET_GetNamedBufferPointerv(exec, _mesa_GetNamedBufferPointerv);
      SET_GetNamedBufferSubData(exec, _mesa_GetNamedBufferSubData);
      SET_GetNamedFramebufferAttachmentParameteriv(exec, _mesa_GetNamedFramebufferAttachmentParameteriv);
      SET_GetNamedFramebufferParameteriv(exec, _mesa_GetNamedFramebufferParameteriv);
      SET_GetNamedRenderbufferParameteriv(exec, _mesa_GetNamedRenderbufferParameteriv);
      SET_GetProgramStageiv(exec, _mesa_GetProgramStageiv);
      SET_GetQueryBufferObjecti64v(exec, _mesa_GetQueryBufferObjecti64v);
      SET_GetQueryBufferObjectiv(exec, _mesa_GetQueryBufferObjectiv);
      SET_GetQueryBufferObjectui64v(exec, _mesa_GetQueryBufferObjectui64v);
      SET_GetQueryBufferObjectuiv(exec, _mesa_GetQueryBufferObjectuiv);
      SET_GetSubroutineIndex(exec, _mesa_GetSubroutineIndex);
      SET_GetSubroutineUniformLocation(exec, _mesa_GetSubroutineUniformLocation);
      SET_GetTextureImage(exec, _mesa_GetTextureImage);
      SET_GetTextureLevelParameterfv(exec, _mesa_GetTextureLevelParameterfv);
      SET_GetTextureLevelParameteriv(exec, _mesa_GetTextureLevelParameteriv);
      SET_GetTextureParameterIiv(exec, _mesa_GetTextureParameterIiv);
      SET_GetTextureParameterIuiv(exec, _mesa_GetTextureParameterIuiv);
      SET_GetTextureParameterfv(exec, _mesa_GetTextureParameterfv);
      SET_GetTextureParameteriv(exec, _mesa_GetTextureParameteriv);
      SET_GetTransformFeedbacki64_v(exec, _mesa_GetTransformFeedbacki64_v);
      SET_GetTransformFeedbacki_v(exec, _mesa_GetTransformFeedbacki_v);
      SET_GetTransformFeedbackiv(exec, _mesa_GetTransformFeedbackiv);
      SET_GetUniformSubroutineuiv(exec, _mesa_GetUniformSubroutineuiv);
      SET_GetUniformdv(exec, _mesa_GetUniformdv);
      SET_GetUniformi64vARB(exec, _mesa_GetUniformi64vARB);
      SET_GetUniformui64vARB(exec, _mesa_GetUniformui64vARB);
      SET_GetVertexArrayIndexed64iv(exec, _mesa_GetVertexArrayIndexed64iv);
      SET_GetVertexArrayIndexediv(exec, _mesa_GetVertexArrayIndexediv);
      SET_GetVertexArrayiv(exec, _mesa_GetVertexArrayiv);
      SET_GetVertexAttribLdv(exec, _mesa_GetVertexAttribLdv);
      SET_GetVertexAttribLui64vARB(exec, _mesa_GetVertexAttribLui64vARB);
      SET_GetnUniformi64vARB(exec, _mesa_GetnUniformi64vARB);
      SET_GetnUniformui64vARB(exec, _mesa_GetnUniformui64vARB);
      SET_InvalidateNamedFramebufferData(exec, _mesa_InvalidateNamedFramebufferData);
      SET_InvalidateNamedFramebufferSubData(exec, _mesa_InvalidateNamedFramebufferSubData);
      SET_NamedFramebufferParameteri(exec, _mesa_NamedFramebufferParameteri);
      SET_NamedRenderbufferStorage(exec, _mesa_NamedRenderbufferStorage);
      SET_NamedRenderbufferStorageMultisample(exec, _mesa_NamedRenderbufferStorageMultisample);
      SET_ProgramUniform1i64ARB(exec, _mesa_ProgramUniform1i64ARB);
      SET_ProgramUniform1i64vARB(exec, _mesa_ProgramUniform1i64vARB);
      SET_ProgramUniform1ui64ARB(exec, _mesa_ProgramUniform1ui64ARB);
      SET_ProgramUniform1ui64vARB(exec, _mesa_ProgramUniform1ui64vARB);
      SET_ProgramUniform2i64ARB(exec, _mesa_ProgramUniform2i64ARB);
      SET_ProgramUniform2i64vARB(exec, _mesa_ProgramUniform2i64vARB);
      SET_ProgramUniform2ui64ARB(exec, _mesa_ProgramUniform2ui64ARB);
      SET_ProgramUniform2ui64vARB(exec, _mesa_ProgramUniform2ui64vARB);
      SET_ProgramUniform3i64ARB(exec, _mesa_ProgramUniform3i64ARB);
      SET_ProgramUniform3i64vARB(exec, _mesa_ProgramUniform3i64vARB);
      SET_ProgramUniform3ui64ARB(exec, _mesa_ProgramUniform3ui64ARB);
      SET_ProgramUniform3ui64vARB(exec, _mesa_ProgramUniform3ui64vARB);
      SET_ProgramUniform4i64ARB(exec, _mesa_ProgramUniform4i64ARB);
      SET_ProgramUniform4i64vARB(exec, _mesa_ProgramUniform4i64vARB);
      SET_ProgramUniform4ui64ARB(exec, _mesa_ProgramUniform4ui64ARB);
      SET_ProgramUniform4ui64vARB(exec, _mesa_ProgramUniform4ui64vARB);
      SET_TextureBuffer(exec, _mesa_TextureBuffer);
      SET_TextureBufferRange(exec, _mesa_TextureBufferRange);
      SET_TextureParameterIiv(exec, _mesa_TextureParameterIiv);
      SET_TextureParameterIuiv(exec, _mesa_TextureParameterIuiv);
      SET_TextureParameterf(exec, _mesa_TextureParameterf);
      SET_TextureParameterfv(exec, _mesa_TextureParameterfv);
      SET_TextureParameteri(exec, _mesa_TextureParameteri);
      SET_TextureParameteriv(exec, _mesa_TextureParameteriv);
      SET_TextureStorage2DMultisample(exec, _mesa_TextureStorage2DMultisample);
      SET_TextureStorage3DMultisample(exec, _mesa_TextureStorage3DMultisample);
      SET_TransformFeedbackBufferBase(exec, _mesa_TransformFeedbackBufferBase);
      SET_TransformFeedbackBufferRange(exec, _mesa_TransformFeedbackBufferRange);
      SET_Uniform1d(exec, _mesa_Uniform1d);
      SET_Uniform1dv(exec, _mesa_Uniform1dv);
      SET_Uniform1i64ARB(exec, _mesa_Uniform1i64ARB);
      SET_Uniform1i64vARB(exec, _mesa_Uniform1i64vARB);
      SET_Uniform1ui64ARB(exec, _mesa_Uniform1ui64ARB);
      SET_Uniform1ui64vARB(exec, _mesa_Uniform1ui64vARB);
      SET_Uniform2d(exec, _mesa_Uniform2d);
      SET_Uniform2dv(exec, _mesa_Uniform2dv);
      SET_Uniform2i64ARB(exec, _mesa_Uniform2i64ARB);
      SET_Uniform2i64vARB(exec, _mesa_Uniform2i64vARB);
      SET_Uniform2ui64ARB(exec, _mesa_Uniform2ui64ARB);
      SET_Uniform2ui64vARB(exec, _mesa_Uniform2ui64vARB);
      SET_Uniform3d(exec, _mesa_Uniform3d);
      SET_Uniform3dv(exec, _mesa_Uniform3dv);
      SET_Uniform3i64ARB(exec, _mesa_Uniform3i64ARB);
      SET_Uniform3i64vARB(exec, _mesa_Uniform3i64vARB);
      SET_Uniform3ui64ARB(exec, _mesa_Uniform3ui64ARB);
      SET_Uniform3ui64vARB(exec, _mesa_Uniform3ui64vARB);
      SET_Uniform4d(exec, _mesa_Uniform4d);
      SET_Uniform4dv(exec, _mesa_Uniform4dv);
      SET_Uniform4i64ARB(exec, _mesa_Uniform4i64ARB);
      SET_Uniform4i64vARB(exec, _mesa_Uniform4i64vARB);
      SET_Uniform4ui64ARB(exec, _mesa_Uniform4ui64ARB);
      SET_Uniform4ui64vARB(exec, _mesa_Uniform4ui64vARB);
      SET_UniformMatrix2dv(exec, _mesa_UniformMatrix2dv);
      SET_UniformMatrix2x3dv(exec, _mesa_UniformMatrix2x3dv);
      SET_UniformMatrix2x4dv(exec, _mesa_UniformMatrix2x4dv);
      SET_UniformMatrix3dv(exec, _mesa_UniformMatrix3dv);
      SET_UniformMatrix3x2dv(exec, _mesa_UniformMatrix3x2dv);
      SET_UniformMatrix3x4dv(exec, _mesa_UniformMatrix3x4dv);
      SET_UniformMatrix4dv(exec, _mesa_UniformMatrix4dv);
      SET_UniformMatrix4x2dv(exec, _mesa_UniformMatrix4x2dv);
      SET_UniformMatrix4x3dv(exec, _mesa_UniformMatrix4x3dv);
      SET_UniformSubroutinesuiv(exec, _mesa_UniformSubroutinesuiv);
      SET_VertexArrayAttribFormat(exec, _mesa_VertexArrayAttribFormat);
      SET_VertexArrayAttribIFormat(exec, _mesa_VertexArrayAttribIFormat);
      SET_VertexArrayAttribLFormat(exec, _mesa_VertexArrayAttribLFormat);
   }
   if (ctx->API == API_OPENGL_COMPAT || ctx->API == API_OPENGL_CORE || (ctx->API == API_OPENGLES2 && ctx->Version >= 31)) {
      SET_FramebufferParameteri(exec, _mesa_FramebufferParameteri);
      SET_GetFramebufferParameteriv(exec, _mesa_GetFramebufferParameteriv);
      SET_TexBuffer(exec, _mesa_TexBuffer);
      SET_TexBufferRange(exec, _mesa_TexBufferRange);
   }
   if (ctx->API == API_OPENGL_CORE || (ctx->API == API_OPENGLES2 && ctx->Version >= 30)) {
      SET_FramebufferParameteriMESA(exec, _mesa_FramebufferParameteriMESA);
      SET_GetFramebufferParameterivMESA(exec, _mesa_GetFramebufferParameterivMESA);
   }

}

